' Copyright (c) Microsoft Corporation.  All Rights Reserved.  See License.txt in the project root for license information.

Option Strict On
Option Explicit On

Imports System

Namespace My.Resources
    
    'This class was auto-generated by the StronglyTypedResourceBuilder
    'class via a tool like ResGen or Visual Studio.
    'To add or remove a member, edit your .ResX file then rerun ResGen
    'with the /str option, or rebuild your VS project.
    '''<summary>
    '''  A strongly-typed resource class, for looking up localized strings, etc.
    '''</summary>
    <Global.System.CodeDom.Compiler.GeneratedCodeAttribute("System.Resources.Tools.StronglyTypedResourceBuilder", "2.0.0.0"),  _
     Global.System.Diagnostics.DebuggerNonUserCodeAttribute(),  _
     Global.System.Runtime.CompilerServices.CompilerGeneratedAttribute()>  _
    Friend Class Microsoft_VisualStudio_Editors_Designer
        
        Private Shared resourceMan As Global.System.Resources.ResourceManager
        
        Private Shared resourceCulture As Global.System.Globalization.CultureInfo
        
        <Global.System.Diagnostics.CodeAnalysis.SuppressMessageAttribute("Microsoft.Performance", "CA1811:AvoidUncalledPrivateCode")>  _
        Friend Sub New()
            MyBase.New
        End Sub
        
        '''<summary>
        '''  Returns the cached ResourceManager instance used by this class.
        '''</summary>
        <Global.System.ComponentModel.EditorBrowsableAttribute(Global.System.ComponentModel.EditorBrowsableState.Advanced)>  _
        Friend Shared ReadOnly Property ResourceManager() As Global.System.Resources.ResourceManager
            Get
                If Object.ReferenceEquals(resourceMan, Nothing) Then
                    Dim temp As Global.System.Resources.ResourceManager = New Global.System.Resources.ResourceManager("Microsoft.VisualStudio.Editors.Designer", GetType(Microsoft_VisualStudio_Editors_Designer).Assembly)
                    resourceMan = temp
                End If
                Return resourceMan
            End Get
        End Property
        
        '''<summary>
        '''  Overrides the current thread's CurrentUICulture property for all
        '''  resource lookups using this strongly typed resource class.
        '''</summary>
        <Global.System.ComponentModel.EditorBrowsableAttribute(Global.System.ComponentModel.EditorBrowsableState.Advanced)>  _
        Friend Shared Property Culture() As Global.System.Globalization.CultureInfo
            Get
                Return resourceCulture
            End Get
            Set
                resourceCulture = value
            End Set
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to This project does not contain a default resources file.  Click here to create one..
        '''</summary>
        Friend Shared ReadOnly Property APPDES_ClickHereCreateResx() As String
            Get
                Return ResourceManager.GetString("APPDES_ClickHereCreateResx", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to This project does not contain a default settings file.  Click here to create one..
        '''</summary>
        Friend Shared ReadOnly Property APPDES_ClickHereCreateSettings() As String
            Get
                Return ResourceManager.GetString("APPDES_ClickHereCreateSettings", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to The designer cannot be shown because the document for it was never loaded..
        '''</summary>
        Friend Shared ReadOnly Property APPDES_DesignerLoader_NotDeferred() As String
            Get
                Return ResourceManager.GetString("APPDES_DesignerLoader_NotDeferred", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to The file &apos;{0}&apos; is already open in an editor.  Please close the file and try again..
        '''</summary>
        Friend Shared ReadOnly Property APPDES_EditorAlreadyOpen_1Arg() As String
            Get
                Return ResourceManager.GetString("APPDES_EditorAlreadyOpen_1Arg", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to An error occurred trying to load the project properties window.  Close the window and try again.
        '''{0}.
        '''</summary>
        Friend Shared ReadOnly Property APPDES_ErrorLoading_Msg() As String
            Get
                Return ResourceManager.GetString("APPDES_ErrorLoading_Msg", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to An error occurred trying to load the page..
        '''</summary>
        Friend Shared ReadOnly Property APPDES_ErrorLoadingPropPage() As String
            Get
                Return ResourceManager.GetString("APPDES_ErrorLoadingPropPage", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Could not find the file &apos;{0}&apos;..
        '''</summary>
        Friend Shared ReadOnly Property APPDES_FileNotFound_1Arg() As String
            Get
                Return ResourceManager.GetString("APPDES_FileNotFound_1Arg", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Project Designer Page Container.
        '''</summary>
        Friend Shared ReadOnly Property APPDES_HostingPanelName() As String
            Get
                Return ResourceManager.GetString("APPDES_HostingPanelName", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to All Project Designer Pages.
        '''</summary>
        Friend Shared ReadOnly Property APPDES_OverflowButton_AccessibilityName() As String
            Get
                Return ResourceManager.GetString("APPDES_OverflowButton_AccessibilityName", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to More Settings.
        '''</summary>
        Friend Shared ReadOnly Property APPDES_OverflowButton_Tooltip() As String
            Get
                Return ResourceManager.GetString("APPDES_OverflowButton_Tooltip", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to {0} page:.
        '''</summary>
        Friend Shared ReadOnly Property APPDES_PageName() As String
            Get
                Return ResourceManager.GetString("APPDES_PageName", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Resources.
        '''</summary>
        Friend Shared ReadOnly Property APPDES_ResourceTabTitle() As String
            Get
                Return ResourceManager.GetString("APPDES_ResourceTabTitle", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Settings.
        '''</summary>
        Friend Shared ReadOnly Property APPDES_SettingsTabTitle() As String
            Get
                Return ResourceManager.GetString("APPDES_SettingsTabTitle", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to The requested file type is not supported in projects of this type..
        '''</summary>
        Friend Shared ReadOnly Property APPDES_SpecialFileNotSupported() As String
            Get
                Return ResourceManager.GetString("APPDES_SpecialFileNotSupported", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Switch Project Designer Page.
        '''</summary>
        Friend Shared ReadOnly Property APPDES_TabButtonDefaultAction() As String
            Get
                Return ResourceManager.GetString("APPDES_TabButtonDefaultAction", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Allow switching between active pages of the project designer (use Ctrl+PageUp and Ctrl+PageDown).
        '''</summary>
        Friend Shared ReadOnly Property APPDES_TabListDescription() As String
            Get
                Return ResourceManager.GetString("APPDES_TabListDescription", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Project Designer.
        '''</summary>
        Friend Shared ReadOnly Property APPDES_Title() As String
            Get
                Return ResourceManager.GetString("APPDES_Title", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Action.
        '''</summary>
        Friend Shared ReadOnly Property AttrEditor_CAT_Action() As String
            Get
                Return ResourceManager.GetString("AttrEditor_CAT_Action", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Appearance.
        '''</summary>
        Friend Shared ReadOnly Property AttrEditor_CAT_Appearance() As String
            Get
                Return ResourceManager.GetString("AttrEditor_CAT_Appearance", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Behavior.
        '''</summary>
        Friend Shared ReadOnly Property AttrEditor_CAT_Behavior() As String
            Get
                Return ResourceManager.GetString("AttrEditor_CAT_Behavior", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Data.
        '''</summary>
        Friend Shared ReadOnly Property AttrEditor_CAT_Data() As String
            Get
                Return ResourceManager.GetString("AttrEditor_CAT_Data", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Default.
        '''</summary>
        Friend Shared ReadOnly Property AttrEditor_CAT_Default() As String
            Get
                Return ResourceManager.GetString("AttrEditor_CAT_Default", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to DragDrop.
        '''</summary>
        Friend Shared ReadOnly Property AttrEditor_CAT_DragDrop() As String
            Get
                Return ResourceManager.GetString("AttrEditor_CAT_DragDrop", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Focus.
        '''</summary>
        Friend Shared ReadOnly Property AttrEditor_CAT_Focus() As String
            Get
                Return ResourceManager.GetString("AttrEditor_CAT_Focus", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Format.
        '''</summary>
        Friend Shared ReadOnly Property AttrEditor_CAT_Format() As String
            Get
                Return ResourceManager.GetString("AttrEditor_CAT_Format", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Key.
        '''</summary>
        Friend Shared ReadOnly Property AttrEditor_CAT_Key() As String
            Get
                Return ResourceManager.GetString("AttrEditor_CAT_Key", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Layout.
        '''</summary>
        Friend Shared ReadOnly Property AttrEditor_CAT_Layout() As String
            Get
                Return ResourceManager.GetString("AttrEditor_CAT_Layout", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Mouse.
        '''</summary>
        Friend Shared ReadOnly Property AttrEditor_CAT_Mouse() As String
            Get
                Return ResourceManager.GetString("AttrEditor_CAT_Mouse", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to WindowStyle.
        '''</summary>
        Friend Shared ReadOnly Property AttrEditor_CAT_WindowStyle() As String
            Get
                Return ResourceManager.GetString("AttrEditor_CAT_WindowStyle", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Category group for the property..
        '''</summary>
        Friend Shared ReadOnly Property AttrEditor_CategoryAttrDescription() As String
            Get
                Return ResourceManager.GetString("AttrEditor_CategoryAttrDescription", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Category.
        '''</summary>
        Friend Shared ReadOnly Property AttrEditor_CategoryAttrDisplayName() As String
            Get
                Return ResourceManager.GetString("AttrEditor_CategoryAttrDisplayName", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Category.
        '''</summary>
        Friend Shared ReadOnly Property AttrEditor_CategoryAttrName() As String
            Get
                Return ResourceManager.GetString("AttrEditor_CategoryAttrName", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to COM.
        '''</summary>
        Friend Shared ReadOnly Property AttrEditor_CategoryCOM() As String
            Get
                Return ResourceManager.GetString("AttrEditor_CategoryCOM", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Component Design.
        '''</summary>
        Friend Shared ReadOnly Property AttrEditor_CategoryComponentModel() As String
            Get
                Return ResourceManager.GetString("AttrEditor_CategoryComponentModel", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Serialization.
        '''</summary>
        Friend Shared ReadOnly Property AttrEditor_CategorySerialization() As String
            Get
                Return ResourceManager.GetString("AttrEditor_CategorySerialization", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Web.
        '''</summary>
        Friend Shared ReadOnly Property AttrEditor_CategoryWeb() As String
            Get
                Return ResourceManager.GetString("AttrEditor_CategoryWeb", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Expose {0} to COM..
        '''</summary>
        Friend Shared ReadOnly Property AttrEditor_COMClassAttrDescription() As String
            Get
                Return ResourceManager.GetString("AttrEditor_COMClassAttrDescription", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to COM Class.
        '''</summary>
        Friend Shared ReadOnly Property AttrEditor_COMClassAttrDisplayName() As String
            Get
                Return ResourceManager.GetString("AttrEditor_COMClassAttrDisplayName", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to COMClass.
        '''</summary>
        Friend Shared ReadOnly Property AttrEditor_COMClassAttrName() As String
            Get
                Return ResourceManager.GetString("AttrEditor_COMClassAttrName", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Make {0} visible through COM..
        '''</summary>
        Friend Shared ReadOnly Property AttrEditor_COMVisibleAttrDescription() As String
            Get
                Return ResourceManager.GetString("AttrEditor_COMVisibleAttrDescription", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to COM Visible.
        '''</summary>
        Friend Shared ReadOnly Property AttrEditor_COMVisibleAttrDisplayName() As String
            Get
                Return ResourceManager.GetString("AttrEditor_COMVisibleAttrDisplayName", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to COMVisible.
        '''</summary>
        Friend Shared ReadOnly Property AttrEditor_COMVisibleAttrName() As String
            Get
                Return ResourceManager.GetString("AttrEditor_COMVisibleAttrName", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to (None).
        '''</summary>
        Friend Shared ReadOnly Property AttrEditor_DE_None() As String
            Get
                Return ResourceManager.GetString("AttrEditor_DE_None", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Default event for the class..
        '''</summary>
        Friend Shared ReadOnly Property AttrEditor_DefaultEventAttrDescription() As String
            Get
                Return ResourceManager.GetString("AttrEditor_DefaultEventAttrDescription", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Default Event.
        '''</summary>
        Friend Shared ReadOnly Property AttrEditor_DefaultEventAttrDisplayName() As String
            Get
                Return ResourceManager.GetString("AttrEditor_DefaultEventAttrDisplayName", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Default Event.
        '''</summary>
        Friend Shared ReadOnly Property AttrEditor_DefaultEventAttrName() As String
            Get
                Return ResourceManager.GetString("AttrEditor_DefaultEventAttrName", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Default value for the property..
        '''</summary>
        Friend Shared ReadOnly Property AttrEditor_DefaultValueAttrDescription() As String
            Get
                Return ResourceManager.GetString("AttrEditor_DefaultValueAttrDescription", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Default Value.
        '''</summary>
        Friend Shared ReadOnly Property AttrEditor_DefaultValueAttrDisplayName() As String
            Get
                Return ResourceManager.GetString("AttrEditor_DefaultValueAttrDisplayName", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Default Value.
        '''</summary>
        Friend Shared ReadOnly Property AttrEditor_DefaultValueAttrName() As String
            Get
                Return ResourceManager.GetString("AttrEditor_DefaultValueAttrName", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Set explicit DispId to this {0}..
        '''</summary>
        Friend Shared ReadOnly Property AttrEditor_DispIdAttrDescription() As String
            Get
                Return ResourceManager.GetString("AttrEditor_DispIdAttrDescription", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to DispId.
        '''</summary>
        Friend Shared ReadOnly Property AttrEditor_DispIdAttrDisplayName() As String
            Get
                Return ResourceManager.GetString("AttrEditor_DispIdAttrDisplayName", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to DispId.
        '''</summary>
        Friend Shared ReadOnly Property AttrEditor_DispIdAttrName() As String
            Get
                Return ResourceManager.GetString("AttrEditor_DispIdAttrName", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to DispId value should be an integer greater than or equal to 1..
        '''</summary>
        Friend Shared ReadOnly Property AttrEditor_DispIdInvalidValue() As String
            Get
                Return ResourceManager.GetString("AttrEditor_DispIdInvalidValue", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Explicit DispId value for this {0}..
        '''</summary>
        Friend Shared ReadOnly Property AttrEditor_DispIdPropDescription() As String
            Get
                Return ResourceManager.GetString("AttrEditor_DispIdPropDescription", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Value.
        '''</summary>
        Friend Shared ReadOnly Property AttrEditor_DispIdPropDisplayName() As String
            Get
                Return ResourceManager.GetString("AttrEditor_DispIdPropDisplayName", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Value.
        '''</summary>
        Friend Shared ReadOnly Property AttrEditor_DispIdPropName() As String
            Get
                Return ResourceManager.GetString("AttrEditor_DispIdPropName", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Field should not be serialized..
        '''</summary>
        Friend Shared ReadOnly Property AttrEditor_NonSerializedAttrDescription() As String
            Get
                Return ResourceManager.GetString("AttrEditor_NonSerializedAttrDescription", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Non Serialized.
        '''</summary>
        Friend Shared ReadOnly Property AttrEditor_NonSerializedAttrDisplayName() As String
            Get
                Return ResourceManager.GetString("AttrEditor_NonSerializedAttrDisplayName", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to NonSerialized.
        '''</summary>
        Friend Shared ReadOnly Property AttrEditor_NonSerializedAttrName() As String
            Get
                Return ResourceManager.GetString("AttrEditor_NonSerializedAttrName", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Enable serialization for this {0} and its members..
        '''</summary>
        Friend Shared ReadOnly Property AttrEditor_SerializableAttrDescription() As String
            Get
                Return ResourceManager.GetString("AttrEditor_SerializableAttrDescription", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Serializable.
        '''</summary>
        Friend Shared ReadOnly Property AttrEditor_SerializableAttrDisplayName() As String
            Get
                Return ResourceManager.GetString("AttrEditor_SerializableAttrDisplayName", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Serializable.
        '''</summary>
        Friend Shared ReadOnly Property AttrEditor_SerializableAttrName() As String
            Get
                Return ResourceManager.GetString("AttrEditor_SerializableAttrName", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Expose method via web services..
        '''</summary>
        Friend Shared ReadOnly Property AttrEditor_WebMethodAttrDescription() As String
            Get
                Return ResourceManager.GetString("AttrEditor_WebMethodAttrDescription", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Web Method.
        '''</summary>
        Friend Shared ReadOnly Property AttrEditor_WebMethodAttrDisplayName() As String
            Get
                Return ResourceManager.GetString("AttrEditor_WebMethodAttrDisplayName", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to WebMethod.
        '''</summary>
        Friend Shared ReadOnly Property AttrEditor_WebMethodAttrName() As String
            Get
                Return ResourceManager.GetString("AttrEditor_WebMethodAttrName", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Description for the Web Method..
        '''</summary>
        Friend Shared ReadOnly Property AttrEditor_WebMethodDescDescription() As String
            Get
                Return ResourceManager.GetString("AttrEditor_WebMethodDescDescription", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Description.
        '''</summary>
        Friend Shared ReadOnly Property AttrEditor_WebMethodDescDisplayName() As String
            Get
                Return ResourceManager.GetString("AttrEditor_WebMethodDescDisplayName", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Description.
        '''</summary>
        Friend Shared ReadOnly Property AttrEditor_WebMethodDescName() As String
            Get
                Return ResourceManager.GetString("AttrEditor_WebMethodDescName", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Maintain session state..
        '''</summary>
        Friend Shared ReadOnly Property AttrEditor_WebMethodEnableSessionDescription() As String
            Get
                Return ResourceManager.GetString("AttrEditor_WebMethodEnableSessionDescription", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Enable Session.
        '''</summary>
        Friend Shared ReadOnly Property AttrEditor_WebMethodEnableSessionDisplayName() As String
            Get
                Return ResourceManager.GetString("AttrEditor_WebMethodEnableSessionDisplayName", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to EnableSession.
        '''</summary>
        Friend Shared ReadOnly Property AttrEditor_WebMethodEnableSessionName() As String
            Get
                Return ResourceManager.GetString("AttrEditor_WebMethodEnableSessionName", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Set transaction options..
        '''</summary>
        Friend Shared ReadOnly Property AttrEditor_WebMethodTransactionDescription() As String
            Get
                Return ResourceManager.GetString("AttrEditor_WebMethodTransactionDescription", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Transaction Options.
        '''</summary>
        Friend Shared ReadOnly Property AttrEditor_WebMethodTransactionDisplayName() As String
            Get
                Return ResourceManager.GetString("AttrEditor_WebMethodTransactionDisplayName", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to TransactionOptions.
        '''</summary>
        Friend Shared ReadOnly Property AttrEditor_WebMethodTransactionName() As String
            Get
                Return ResourceManager.GetString("AttrEditor_WebMethodTransactionName", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Configure the Web Service settings..
        '''</summary>
        Friend Shared ReadOnly Property AttrEditor_WebServiceAttrDescription() As String
            Get
                Return ResourceManager.GetString("AttrEditor_WebServiceAttrDescription", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Web Service.
        '''</summary>
        Friend Shared ReadOnly Property AttrEditor_WebServiceAttrDisplayName() As String
            Get
                Return ResourceManager.GetString("AttrEditor_WebServiceAttrDisplayName", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to WebService.
        '''</summary>
        Friend Shared ReadOnly Property AttrEditor_WebServiceAttrName() As String
            Get
                Return ResourceManager.GetString("AttrEditor_WebServiceAttrName", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Description for the web service..
        '''</summary>
        Friend Shared ReadOnly Property AttrEditor_WebServiceDescDescription() As String
            Get
                Return ResourceManager.GetString("AttrEditor_WebServiceDescDescription", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Description.
        '''</summary>
        Friend Shared ReadOnly Property AttrEditor_WebServiceDescDisplayName() As String
            Get
                Return ResourceManager.GetString("AttrEditor_WebServiceDescDisplayName", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Description.
        '''</summary>
        Friend Shared ReadOnly Property AttrEditor_WebServiceDescName() As String
            Get
                Return ResourceManager.GetString("AttrEditor_WebServiceDescName", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Name for the web service..
        '''</summary>
        Friend Shared ReadOnly Property AttrEditor_WebServiceNameDescription() As String
            Get
                Return ResourceManager.GetString("AttrEditor_WebServiceNameDescription", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Name.
        '''</summary>
        Friend Shared ReadOnly Property AttrEditor_WebServiceNameDisplayName() As String
            Get
                Return ResourceManager.GetString("AttrEditor_WebServiceNameDisplayName", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Name.
        '''</summary>
        Friend Shared ReadOnly Property AttrEditor_WebServiceNameName() As String
            Get
                Return ResourceManager.GetString("AttrEditor_WebServiceNameName", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Namespace for the web service..
        '''</summary>
        Friend Shared ReadOnly Property AttrEditor_WebServiceNSDescription() As String
            Get
                Return ResourceManager.GetString("AttrEditor_WebServiceNSDescription", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Namespace.
        '''</summary>
        Friend Shared ReadOnly Property AttrEditor_WebServiceNSDisplayName() As String
            Get
                Return ResourceManager.GetString("AttrEditor_WebServiceNSDisplayName", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Namespace.
        '''</summary>
        Friend Shared ReadOnly Property AttrEditor_WebServiceNSName() As String
            Get
                Return ResourceManager.GetString("AttrEditor_WebServiceNSName", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to All Files.
        '''</summary>
        Friend Shared ReadOnly Property CMN_AllFilesFilter() As String
            Get
                Return ResourceManager.GetString("CMN_AllFilesFilter", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Buffer is read only..
        '''</summary>
        Friend Shared ReadOnly Property DFX_BufferReadOnly() As String
            Get
                Return ResourceManager.GetString("DFX_BufferReadOnly", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Unable to create the designer.  {0}.
        '''</summary>
        Friend Shared ReadOnly Property DFX_CreateEditorInstanceFailed_Ex() As String
            Get
                Return ResourceManager.GetString("DFX_CreateEditorInstanceFailed_Ex", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to The editor could not get the IVsTextStream for file {0}..
        '''</summary>
        Friend Shared ReadOnly Property DFX_DesignerLoaderIVsTextStreamNotFound() As String
            Get
                Return ResourceManager.GetString("DFX_DesignerLoaderIVsTextStreamNotFound", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to The editor could not get the IVsTextStream..
        '''</summary>
        Friend Shared ReadOnly Property DFX_DesignerLoaderIVsTextStreamNotFoundNoFile() As String
            Get
                Return ResourceManager.GetString("DFX_DesignerLoaderIVsTextStreamNotFoundNoFile", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to {0} [Read Only].
        '''</summary>
        Friend Shared ReadOnly Property DFX_DesignerReadOnlyCaption() As String
            Get
                Return ResourceManager.GetString("DFX_DesignerReadOnlyCaption", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to No DesignerService for file &apos;{0}&apos;..
        '''</summary>
        Friend Shared ReadOnly Property DFX_EditorNoDesignerService() As String
            Get
                Return ResourceManager.GetString("DFX_EditorNoDesignerService", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Microsoft Visual Studio.
        '''</summary>
        Friend Shared ReadOnly Property DFX_Error_Default_Caption() As String
            Get
                Return ResourceManager.GetString("DFX_Error_Default_Caption", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to File is already opened in an incompatible editor..
        '''</summary>
        Friend Shared ReadOnly Property DFX_IncompatibleBuffer() As String
            Get
                Return ResourceManager.GetString("DFX_IncompatibleBuffer", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Invalid physical view name..
        '''</summary>
        Friend Shared ReadOnly Property DFX_InvalidPhysicalViewName() As String
            Get
                Return ResourceManager.GetString("DFX_InvalidPhysicalViewName", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to No LocalRegistry service..
        '''</summary>
        Friend Shared ReadOnly Property DFX_NoLocalRegistry() As String
            Get
                Return ResourceManager.GetString("DFX_NoLocalRegistry", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Unsupported format..
        '''</summary>
        Friend Shared ReadOnly Property DFX_NotSupported() As String
            Get
                Return ResourceManager.GetString("DFX_NotSupported", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to One or more files were reloaded during the checkout. Please retry your operation..
        '''</summary>
        Friend Shared ReadOnly Property DFX_OneOrMoreFilesReloaded() As String
            Get
                Return ResourceManager.GetString("DFX_OneOrMoreFilesReloaded", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Replacing text stream failed:{0}.
        '''</summary>
        Friend Shared ReadOnly Property DFX_ReplaceTextStreamFailed() As String
            Get
                Return ResourceManager.GetString("DFX_ReplaceTextStreamFailed", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Unable to create text buffer..
        '''</summary>
        Friend Shared ReadOnly Property DFX_UnableCreateTextBuffer() As String
            Get
                Return ResourceManager.GetString("DFX_UnableCreateTextBuffer", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Unable to check out the current file.  The file may be read-only or locked, or you may need to check the file out manually..
        '''</summary>
        Friend Shared ReadOnly Property DFX_UnableToCheckout() As String
            Get
                Return ResourceManager.GetString("DFX_UnableToCheckout", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Unknown Error..
        '''</summary>
        Friend Shared ReadOnly Property DFX_WindowPane_UnknownError() As String
            Get
                Return ResourceManager.GetString("DFX_WindowPane_UnknownError", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Invalid argument &apos;{0}&apos;.
        '''</summary>
        Friend Shared ReadOnly Property General_InvalidArgument_1Arg() As String
            Get
                Return ResourceManager.GetString("General_InvalidArgument_1Arg", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Unable to find service &apos;{0}&apos;.  Ensure that the application is installed correctly..
        '''</summary>
        Friend Shared ReadOnly Property General_MissingService() As String
            Get
                Return ResourceManager.GetString("General_MissingService", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Please enter an integer between 1 and 60..
        '''</summary>
        Friend Shared ReadOnly Property OptionPage_Editor_InvalidIndentSize() As String
            Get
                Return ResourceManager.GetString("OptionPage_Editor_InvalidIndentSize", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Please enter an integer between 1 and 60..
        '''</summary>
        Friend Shared ReadOnly Property OptionPage_Editor_InvalidTabSize() As String
            Get
                Return ResourceManager.GetString("OptionPage_Editor_InvalidTabSize", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Changes in Help Options will not take effect until the environment is restarted..
        '''</summary>
        Friend Shared ReadOnly Property OptionPage_Environment_ShowHelpOptionRequiresRestartOfIde() As String
            Get
                Return ResourceManager.GetString("OptionPage_Environment_ShowHelpOptionRequiresRestartOfIde", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Load last loaded solution.
        '''</summary>
        Friend Shared ReadOnly Property OptionPage_Environment_StartUpLoadLastLoadedSolution() As String
            Get
                Return ResourceManager.GetString("OptionPage_Environment_StartUpLoadLastLoadedSolution", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Show empty environment.
        '''</summary>
        Friend Shared ReadOnly Property OptionPage_Environment_StartUpShowEmptyEnvironment() As String
            Get
                Return ResourceManager.GetString("OptionPage_Environment_StartUpShowEmptyEnvironment", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Show New Project dialog box.
        '''</summary>
        Friend Shared ReadOnly Property OptionPage_Environment_StartUpShowNewProjectDialogBox() As String
            Get
                Return ResourceManager.GetString("OptionPage_Environment_StartUpShowNewProjectDialogBox", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Show Open Project dialog box.
        '''</summary>
        Friend Shared ReadOnly Property OptionPage_Environment_StartUpShowOpenProjectDialogBox() As String
            Get
                Return ResourceManager.GetString("OptionPage_Environment_StartUpShowOpenProjectDialogBox", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to The location specified is on an invalid or read-only disk, or contains a device name reserved for the system..
        '''</summary>
        Friend Shared ReadOnly Property OptionPage_Project_IllegalDefaultProjectDirectory() As String
            Get
                Return ResourceManager.GetString("OptionPage_Project_IllegalDefaultProjectDirectory", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Requires:.
        '''</summary>
        Friend Shared ReadOnly Property PermissionSet_Requires() As String
            Get
                Return ResourceManager.GetString("PermissionSet_Requires", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Active ({0}).
        '''</summary>
        Friend Shared ReadOnly Property PPG_ActiveConfigOrPlatformFormatString_1Arg() As String
            Get
                Return ResourceManager.GetString("PPG_ActiveConfigOrPlatformFormatString_1Arg", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Add existing file to project.
        '''</summary>
        Friend Shared ReadOnly Property PPG_AddExistingFilesTitle() As String
            Get
                Return ResourceManager.GetString("PPG_AddExistingFilesTitle", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Icon Files.
        '''</summary>
        Friend Shared ReadOnly Property PPG_AddIconFilesFilter() As String
            Get
                Return ResourceManager.GetString("PPG_AddIconFilesFilter", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Win32 Resource Files.
        '''</summary>
        Friend Shared ReadOnly Property PPG_AddWin32ResourceFilter() As String
            Get
                Return ResourceManager.GetString("PPG_AddWin32ResourceFilter", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Add Win32 resource file to project.
        '''</summary>
        Friend Shared ReadOnly Property PPG_AddWin32ResourceTitle() As String
            Get
                Return ResourceManager.GetString("PPG_AddWin32ResourceTitle", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Base address must be a hexadecimal number with less than or equal to 8 digits, for example, 0x11000000..
        '''</summary>
        Friend Shared ReadOnly Property PPG_AdvancedBuildSettings_InvalidBaseAddress() As String
            Get
                Return ResourceManager.GetString("PPG_AdvancedBuildSettings_InvalidBaseAddress", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Advanced Build Settings.
        '''</summary>
        Friend Shared ReadOnly Property PPG_AdvancedBuildSettings_Title() As String
            Get
                Return ResourceManager.GetString("PPG_AdvancedBuildSettings_Title", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Advanced Compiler Settings.
        '''</summary>
        Friend Shared ReadOnly Property PPG_AdvancedCompilerSettings_Title() As String
            Get
                Return ResourceManager.GetString("PPG_AdvancedCompilerSettings_Title", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to All Configurations.
        '''</summary>
        Friend Shared ReadOnly Property PPG_AllConfigurations() As String
            Get
                Return ResourceManager.GetString("PPG_AllConfigurations", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to All Platforms.
        '''</summary>
        Friend Shared ReadOnly Property PPG_AllPlatforms() As String
            Get
                Return ResourceManager.GetString("PPG_AllPlatforms", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to The following events are available for MyApplication:.
        '''</summary>
        Friend Shared ReadOnly Property PPG_Application_AppEventsCommentLine1() As String
            Get
                Return ResourceManager.GetString("PPG_Application_AppEventsCommentLine1", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to .
        '''</summary>
        Friend Shared ReadOnly Property PPG_Application_AppEventsCommentLine2() As String
            Get
                Return ResourceManager.GetString("PPG_Application_AppEventsCommentLine2", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Startup: Raised when the application starts, before the startup form is created..
        '''</summary>
        Friend Shared ReadOnly Property PPG_Application_AppEventsCommentLine3() As String
            Get
                Return ResourceManager.GetString("PPG_Application_AppEventsCommentLine3", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Shutdown: Raised after all application forms are closed.  This event is not raised if the application terminates abnormally..
        '''</summary>
        Friend Shared ReadOnly Property PPG_Application_AppEventsCommentLine4() As String
            Get
                Return ResourceManager.GetString("PPG_Application_AppEventsCommentLine4", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to UnhandledException: Raised if the application encounters an unhandled exception..
        '''</summary>
        Friend Shared ReadOnly Property PPG_Application_AppEventsCommentLine5() As String
            Get
                Return ResourceManager.GetString("PPG_Application_AppEventsCommentLine5", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to StartupNextInstance: Raised when launching a single-instance application and the application is already active. .
        '''</summary>
        Friend Shared ReadOnly Property PPG_Application_AppEventsCommentLine6() As String
            Get
                Return ResourceManager.GetString("PPG_Application_AppEventsCommentLine6", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to NetworkAvailabilityChanged: Raised when the network connection is connected or disconnected..
        '''</summary>
        Friend Shared ReadOnly Property PPG_Application_AppEventsCommentLine7() As String
            Get
                Return ResourceManager.GetString("PPG_Application_AppEventsCommentLine7", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to The GUID should match the format dddddddd-dddd-dddd-dddd-dddddddddddd..
        '''</summary>
        Friend Shared ReadOnly Property PPG_Application_BadGuid() As String
            Get
                Return ResourceManager.GetString("PPG_Application_BadGuid", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Invalid icon file..
        '''</summary>
        Friend Shared ReadOnly Property PPG_Application_BadIcon() As String
            Get
                Return ResourceManager.GetString("PPG_Application_BadIcon", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to {0} is not a valid icon file..
        '''</summary>
        Friend Shared ReadOnly Property PPG_Application_BadIcon_1Arg() As String
            Get
                Return ResourceManager.GetString("PPG_Application_BadIcon_1Arg", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Invalid manifest file..
        '''</summary>
        Friend Shared ReadOnly Property PPG_Application_BadManifest() As String
            Get
                Return ResourceManager.GetString("PPG_Application_BadManifest", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Icon could not be added to the project..
        '''</summary>
        Friend Shared ReadOnly Property PPG_Application_CantAddIcon() As String
            Get
                Return ResourceManager.GetString("PPG_Application_CantAddIcon", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to (Default Icon).
        '''</summary>
        Friend Shared ReadOnly Property PPG_Application_DefaultIconText() As String
            Get
                Return ResourceManager.GetString("PPG_Application_DefaultIconText", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Embed manifest with default settings.
        '''</summary>
        Friend Shared ReadOnly Property PPG_Application_DefaultManifestText() As String
            Get
                Return ResourceManager.GetString("PPG_Application_DefaultManifestText", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to &apos;{0}&apos; is not a valid identifier. Please select a different Splash screen form..
        '''</summary>
        Friend Shared ReadOnly Property PPG_Application_InvalidIdentifierSplashScreenForm_1Arg() As String
            Get
                Return ResourceManager.GetString("PPG_Application_InvalidIdentifierSplashScreenForm_1Arg", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to &apos;{0}&apos; is not a valid identifier. Please select a different Startup form..
        '''</summary>
        Friend Shared ReadOnly Property PPG_Application_InvalidIdentifierStartupForm_1Arg() As String
            Get
                Return ResourceManager.GetString("PPG_Application_InvalidIdentifierStartupForm_1Arg", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Startup object must be a form when &apos;Enable application framework&apos; is checked..
        '''</summary>
        Friend Shared ReadOnly Property PPG_Application_InvalidSubMainStartup() As String
            Get
                Return ResourceManager.GetString("PPG_Application_InvalidSubMainStartup", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to NOTE: This file is auto-generated; do not modify it directly.  To make changes,.
        '''</summary>
        Friend Shared ReadOnly Property PPG_Application_MyAppCommentLine1() As String
            Get
                Return ResourceManager.GetString("PPG_Application_MyAppCommentLine1", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to  or if you encounter build errors in this file, go to the Project Designer.
        '''</summary>
        Friend Shared ReadOnly Property PPG_Application_MyAppCommentLine2() As String
            Get
                Return ResourceManager.GetString("PPG_Application_MyAppCommentLine2", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to  (go to Project Properties or double-click the My Project node in.
        '''</summary>
        Friend Shared ReadOnly Property PPG_Application_MyAppCommentLine3() As String
            Get
                Return ResourceManager.GetString("PPG_Application_MyAppCommentLine3", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to  Solution Explorer), and make changes on the Application tab..
        '''</summary>
        Friend Shared ReadOnly Property PPG_Application_MyAppCommentLine4() As String
            Get
                Return ResourceManager.GetString("PPG_Application_MyAppCommentLine4", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to .
        '''</summary>
        Friend Shared ReadOnly Property PPG_Application_MyAppCommentLine5() As String
            Get
                Return ResourceManager.GetString("PPG_Application_MyAppCommentLine5", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Create application without a manifest.
        '''</summary>
        Friend Shared ReadOnly Property PPG_Application_NoManifestText() As String
            Get
                Return ResourceManager.GetString("PPG_Application_NoManifestText", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Default pac&amp;kage:.
        '''</summary>
        Friend Shared ReadOnly Property PPG_Application_RootNamespaceJSharp() As String
            Get
                Return ResourceManager.GetString("PPG_Application_RootNamespaceJSharp", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to The splash screen form cannot be the start-up form..
        '''</summary>
        Friend Shared ReadOnly Property PPG_Application_SplashSameAsStart() As String
            Get
                Return ResourceManager.GetString("PPG_Application_SplashSameAsStart", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Startup f&amp;orm:.
        '''</summary>
        Friend Shared ReadOnly Property PPG_Application_StartupFormLabelText() As String
            Get
                Return ResourceManager.GetString("PPG_Application_StartupFormLabelText", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Startup &amp;object:.
        '''</summary>
        Friend Shared ReadOnly Property PPG_Application_StartupObjectLabelText() As String
            Get
                Return ResourceManager.GetString("PPG_Application_StartupObjectLabelText", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to (Not set).
        '''</summary>
        Friend Shared ReadOnly Property PPG_Application_StartupObjectNotSet() As String
            Get
                Return ResourceManager.GetString("PPG_Application_StartupObjectNotSet", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Startup &amp;URI:.
        '''</summary>
        Friend Shared ReadOnly Property PPG_Application_StartupUriLabelText() As String
            Get
                Return ResourceManager.GetString("PPG_Application_StartupUriLabelText", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Application.
        '''</summary>
        Friend Shared ReadOnly Property PPG_ApplicationTitle() As String
            Get
                Return ResourceManager.GetString("PPG_ApplicationTitle", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to A wildcard (&quot;*&quot;) is not allowed in this field..
        '''</summary>
        Friend Shared ReadOnly Property PPG_AssemblyInfo_BadWildcard() As String
            Get
                Return ResourceManager.GetString("PPG_AssemblyInfo_BadWildcard", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Invalid version format, expected &quot;[Major]&quot;, &quot;[Major].[Minor]&quot;, &quot;[Major].[Minor].[Build]&quot; or &quot;[Major].[Minor].[Build].[Revision]&quot;.
        '''</summary>
        Friend Shared ReadOnly Property PPG_AssemblyInfo_InvalidVersion() As String
            Get
                Return ResourceManager.GetString("PPG_AssemblyInfo_InvalidVersion", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Assembly Information.
        '''</summary>
        Friend Shared ReadOnly Property PPG_AssemblyInfo_Title() As String
            Get
                Return ResourceManager.GetString("PPG_AssemblyInfo_Title", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Each part of the version number for &apos;{0}&apos; must be an integer between 0 and {1}..
        '''</summary>
        Friend Shared ReadOnly Property PPG_AssemblyInfo_VersionOutOfRange_2Args() As String
            Get
                Return ResourceManager.GetString("PPG_AssemblyInfo_VersionOutOfRange_2Args", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to &lt;Browse...&gt;.
        '''</summary>
        Friend Shared ReadOnly Property PPG_BrowseText() As String
            Get
                Return ResourceManager.GetString("PPG_BrowseText", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Build Events.
        '''</summary>
        Friend Shared ReadOnly Property PPG_BuildEventsTitle() As String
            Get
                Return ResourceManager.GetString("PPG_BuildEventsTitle", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Build.
        '''</summary>
        Friend Shared ReadOnly Property PPG_BuildTitle() As String
            Get
                Return ResourceManager.GetString("PPG_BuildTitle", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to (None).
        '''</summary>
        Friend Shared ReadOnly Property PPG_ComboBoxSelect_None() As String
            Get
                Return ResourceManager.GetString("PPG_ComboBoxSelect_None", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Console Application.
        '''</summary>
        Friend Shared ReadOnly Property PPG_CommandLineApp() As String
            Get
                Return ResourceManager.GetString("PPG_CommandLineApp", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to WPF Console Application.
        '''</summary>
        Friend Shared ReadOnly Property PPG_CommandLineApp_WPF() As String
            Get
                Return ResourceManager.GetString("PPG_CommandLineApp_WPF", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Compatible Settings.
        '''</summary>
        Friend Shared ReadOnly Property PPG_CompatibleSettings_Title() As String
            Get
                Return ResourceManager.GetString("PPG_CompatibleSettings_Title", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Recursive operator or property access.
        '''</summary>
        Friend Shared ReadOnly Property PPG_Compile_42004() As String
            Get
                Return ResourceManager.GetString("PPG_Compile_42004", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Implicit conversion.
        '''</summary>
        Friend Shared ReadOnly Property PPG_Compile_42016() As String
            Get
                Return ResourceManager.GetString("PPG_Compile_42016", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Late binding; call could fail at run time.
        '''</summary>
        Friend Shared ReadOnly Property PPG_Compile_42017_42018_42019() As String
            Get
                Return ResourceManager.GetString("PPG_Compile_42017_42018_42019", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Implicit type; object assumed.
        '''</summary>
        Friend Shared ReadOnly Property PPG_Compile_42020() As String
            Get
                Return ResourceManager.GetString("PPG_Compile_42020", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Unused local variable.
        '''</summary>
        Friend Shared ReadOnly Property PPG_Compile_42024() As String
            Get
                Return ResourceManager.GetString("PPG_Compile_42024", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Instance variable accesses shared member.
        '''</summary>
        Friend Shared ReadOnly Property PPG_Compile_42025() As String
            Get
                Return ResourceManager.GetString("PPG_Compile_42025", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Duplicate or overlapping catch blocks.
        '''</summary>
        Friend Shared ReadOnly Property PPG_Compile_42029() As String
            Get
                Return ResourceManager.GetString("PPG_Compile_42029", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Function/Operator without return value.
        '''</summary>
        Friend Shared ReadOnly Property PPG_Compile_420XX() As String
            Get
                Return ResourceManager.GetString("PPG_Compile_420XX", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Use of variable prior to assignment.
        '''</summary>
        Friend Shared ReadOnly Property PPG_Compile_42104() As String
            Get
                Return ResourceManager.GetString("PPG_Compile_42104", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Error.
        '''</summary>
        Friend Shared ReadOnly Property PPG_Compile_Notification_Error() As String
            Get
                Return ResourceManager.GetString("PPG_Compile_Notification_Error", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to None.
        '''</summary>
        Friend Shared ReadOnly Property PPG_Compile_Notification_None() As String
            Get
                Return ResourceManager.GetString("PPG_Compile_Notification_None", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Warning.
        '''</summary>
        Friend Shared ReadOnly Property PPG_Compile_Notification_Warning() As String
            Get
                Return ResourceManager.GetString("PPG_Compile_Notification_Warning", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to (custom).
        '''</summary>
        Friend Shared ReadOnly Property PPG_Compile_OptionStrict_Custom() As String
            Get
                Return ResourceManager.GetString("PPG_Compile_OptionStrict_Custom", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to The warning settings for one or more configurations conflict.
        '''Changing this setting will reset the settings in all configurations..
        '''</summary>
        Friend Shared ReadOnly Property PPG_Compile_ResetIndeterminateWarningLevels() As String
            Get
                Return ResourceManager.GetString("PPG_Compile_ResetIndeterminateWarningLevels", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Compiler Warnings.
        '''</summary>
        Friend Shared ReadOnly Property PPG_CompilerWarnings_Title() As String
            Get
                Return ResourceManager.GetString("PPG_CompilerWarnings_Title", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Compile.
        '''</summary>
        Friend Shared ReadOnly Property PPG_CompileTitle() As String
            Get
                Return ResourceManager.GetString("PPG_CompileTitle", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Could not find the configuration &apos;{0}&apos; for platform &apos;{1}&apos;..
        '''</summary>
        Friend Shared ReadOnly Property PPG_ConfigNotFound_2Args() As String
            Get
                Return ResourceManager.GetString("PPG_ConfigNotFound_2Args", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to (Custom).
        '''</summary>
        Friend Shared ReadOnly Property PPG_CustomPermissionSet() As String
            Get
                Return ResourceManager.GetString("PPG_CustomPermissionSet", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Debug.
        '''</summary>
        Friend Shared ReadOnly Property PPG_DebugTitle() As String
            Get
                Return ResourceManager.GetString("PPG_DebugTitle", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Deploy.
        '''</summary>
        Friend Shared ReadOnly Property PPG_DeployTitle() As String
            Get
                Return ResourceManager.GetString("PPG_DeployTitle", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Executable Files.
        '''</summary>
        Friend Shared ReadOnly Property PPG_ExeFilesFilter() As String
            Get
                Return ResourceManager.GetString("PPG_ExeFilesFilter", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Folder path does not exist.
        '''Please select a valid folder path..
        '''</summary>
        Friend Shared ReadOnly Property PPG_InvalidFolderPath() As String
            Get
                Return ResourceManager.GetString("PPG_InvalidFolderPath", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Base address must be a hexadecimal number with less than or equal to 8 digits, for example, &amp;H11000000..
        '''</summary>
        Friend Shared ReadOnly Property PPG_InvalidHexString() As String
            Get
                Return ResourceManager.GetString("PPG_InvalidHexString", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to &lt;Browse...&gt;.
        '''</summary>
        Friend Shared ReadOnly Property PPG_KeyFileBrowseText() As String
            Get
                Return ResourceManager.GetString("PPG_KeyFileBrowseText", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to &lt;New...&gt;.
        '''</summary>
        Friend Shared ReadOnly Property PPG_KeyFileNewText() As String
            Get
                Return ResourceManager.GetString("PPG_KeyFileNewText", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Aborting....
        '''</summary>
        Friend Shared ReadOnly Property PPG_MgdStatus_Aborting() As String
            Get
                Return ResourceManager.GetString("PPG_MgdStatus_Aborting", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Analyze Failed.
        '''</summary>
        Friend Shared ReadOnly Property PPG_MgdStatus_AnalyzeFailed() As String
            Get
                Return ResourceManager.GetString("PPG_MgdStatus_AnalyzeFailed", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Analyzing....
        '''</summary>
        Friend Shared ReadOnly Property PPG_MgdStatus_Analyzing() As String
            Get
                Return ResourceManager.GetString("PPG_MgdStatus_Analyzing", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Build completed....
        '''</summary>
        Friend Shared ReadOnly Property PPG_MgdStatus_BuildComplete() As String
            Get
                Return ResourceManager.GetString("PPG_MgdStatus_BuildComplete", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Build Failed.  Click CANCEL and correct the build failure before analyzing again..
        '''</summary>
        Friend Shared ReadOnly Property PPG_MgdStatus_BuildFailed() As String
            Get
                Return ResourceManager.GetString("PPG_MgdStatus_BuildFailed", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Serious error.  The build must begin in order to analyze permissions.  It has not started..
        '''</summary>
        Friend Shared ReadOnly Property PPG_MgdStatus_BuildFailedToStart() As String
            Get
                Return ResourceManager.GetString("PPG_MgdStatus_BuildFailedToStart", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Building....
        '''</summary>
        Friend Shared ReadOnly Property PPG_MgdStatus_Building() As String
            Get
                Return ResourceManager.GetString("PPG_MgdStatus_Building", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Unable to start the build..
        '''</summary>
        Friend Shared ReadOnly Property PPG_MgdStatus_BuildUnableToStart() As String
            Get
                Return ResourceManager.GetString("PPG_MgdStatus_BuildUnableToStart", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Canceling....
        '''</summary>
        Friend Shared ReadOnly Property PPG_MgdStatus_Cancelling() As String
            Get
                Return ResourceManager.GetString("PPG_MgdStatus_Cancelling", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Starting....
        '''</summary>
        Friend Shared ReadOnly Property PPG_MgdStatus_Starting() As String
            Get
                Return ResourceManager.GetString("PPG_MgdStatus_Starting", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Stopped....
        '''</summary>
        Friend Shared ReadOnly Property PPG_MgdStatus_Stopped() As String
            Get
                Return ResourceManager.GetString("PPG_MgdStatus_Stopped", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Application-defined.
        '''</summary>
        Friend Shared ReadOnly Property PPG_MyApplication_AuthenMode_ApplicationDefined() As String
            Get
                Return ResourceManager.GetString("PPG_MyApplication_AuthenMode_ApplicationDefined", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Windows.
        '''</summary>
        Friend Shared ReadOnly Property PPG_MyApplication_AuthenMode_Windows() As String
            Get
                Return ResourceManager.GetString("PPG_MyApplication_AuthenMode_Windows", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to When last form closes.
        '''</summary>
        Friend Shared ReadOnly Property PPG_MyApplication_StartupMode_AppExits() As String
            Get
                Return ResourceManager.GetString("PPG_MyApplication_StartupMode_AppExits", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to When startup form closes.
        '''</summary>
        Friend Shared ReadOnly Property PPG_MyApplication_StartupMode_FormCloses() As String
            Get
                Return ResourceManager.GetString("PPG_MyApplication_StartupMode_FormCloses", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to (None).
        '''</summary>
        Friend Shared ReadOnly Property PPG_NeutralLanguage_None() As String
            Get
                Return ResourceManager.GetString("PPG_NeutralLanguage_None", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to (None).
        '''</summary>
        Friend Shared ReadOnly Property PPG_NonePermissionSet() As String
            Get
                Return ResourceManager.GetString("PPG_NonePermissionSet", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to N/A.
        '''</summary>
        Friend Shared ReadOnly Property PPG_NotApplicable() As String
            Get
                Return ResourceManager.GetString("PPG_NotApplicable", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to The output path is not trusted.
        '''The application may throw security exceptions when it attempts to perform actions which require full trust.
        '''Click OK to ignore and continue. Click CANCEL to choose a different output path..
        '''</summary>
        Friend Shared ReadOnly Property PPG_OutputPathNotSecure() As String
            Get
                Return ResourceManager.GetString("PPG_OutputPathNotSecure", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Post-build Event Command Line.
        '''</summary>
        Friend Shared ReadOnly Property PPG_PostBuildCommandLineTitle() As String
            Get
                Return ResourceManager.GetString("PPG_PostBuildCommandLineTitle", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Pre-build Event Command Line.
        '''</summary>
        Friend Shared ReadOnly Property PPG_PreBuildCommandLineTitle() As String
            Get
                Return ResourceManager.GetString("PPG_PreBuildCommandLineTitle", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to The project was reloaded, and some changes on this page may have been lost..
        '''</summary>
        Friend Shared ReadOnly Property PPG_ProjectReloadedSomePropertiesMayNotHaveBeenSet() As String
            Get
                Return ResourceManager.GetString("PPG_ProjectReloadedSomePropertiesMayNotHaveBeenSet", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Application Icon.
        '''</summary>
        Friend Shared ReadOnly Property PPG_Property_ApplicationIcon() As String
            Get
                Return ResourceManager.GetString("PPG_Property_ApplicationIcon", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Assembly File Version.
        '''</summary>
        Friend Shared ReadOnly Property PPG_Property_AssemblyFileVersion() As String
            Get
                Return ResourceManager.GetString("PPG_Property_AssemblyFileVersion", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Assembly GUID.
        '''</summary>
        Friend Shared ReadOnly Property PPG_Property_AssemblyGuid() As String
            Get
                Return ResourceManager.GetString("PPG_Property_AssemblyGuid", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Assembly Name.
        '''</summary>
        Friend Shared ReadOnly Property PPG_Property_AssemblyName() As String
            Get
                Return ResourceManager.GetString("PPG_Property_AssemblyName", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Assembly Version.
        '''</summary>
        Friend Shared ReadOnly Property PPG_Property_AssemblyVersion() As String
            Get
                Return ResourceManager.GetString("PPG_Property_AssemblyVersion", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Enable application framework.
        '''</summary>
        Friend Shared ReadOnly Property PPG_Property_CustomSubMain() As String
            Get
                Return ResourceManager.GetString("PPG_Property_CustomSubMain", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Remote Machine Name.
        '''</summary>
        Friend Shared ReadOnly Property PPG_Property_RemoteDebugMachine() As String
            Get
                Return ResourceManager.GetString("PPG_Property_RemoteDebugMachine", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Root Namespace.
        '''</summary>
        Friend Shared ReadOnly Property PPG_Property_RootNamespace() As String
            Get
                Return ResourceManager.GetString("PPG_Property_RootNamespace", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to External Program Path.
        '''</summary>
        Friend Shared ReadOnly Property PPG_Property_StartProgram() As String
            Get
                Return ResourceManager.GetString("PPG_Property_StartProgram", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Startup Object.
        '''</summary>
        Friend Shared ReadOnly Property PPG_Property_StartupObject() As String
            Get
                Return ResourceManager.GetString("PPG_Property_StartupObject", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Start Browser With URL.
        '''</summary>
        Friend Shared ReadOnly Property PPG_Property_StartURL() As String
            Get
                Return ResourceManager.GetString("PPG_Property_StartURL", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Working Directory.
        '''</summary>
        Friend Shared ReadOnly Property PPG_Property_StartWorkingDirectory() As String
            Get
                Return ResourceManager.GetString("PPG_Property_StartWorkingDirectory", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Property Page.
        '''</summary>
        Friend Shared ReadOnly Property PPG_PropertyPageControlName() As String
            Get
                Return ResourceManager.GetString("PPG_PropertyPageControlName", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Adding web reference failed. {0}
        '''.
        '''</summary>
        Friend Shared ReadOnly Property PPG_Reference_AddWebReference() As String
            Get
                Return ResourceManager.GetString("PPG_Reference_AddWebReference", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Cannot remove &apos;{0}&apos;. {1}
        '''.
        '''</summary>
        Friend Shared ReadOnly Property PPG_Reference_CanNotRemoveReference() As String
            Get
                Return ResourceManager.GetString("PPG_Reference_CanNotRemoveReference", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Updating web reference &apos;{0}&apos; failed.
        '''{1}.
        '''</summary>
        Friend Shared ReadOnly Property PPG_Reference_FailedToUpdateWebReference() As String
            Get
                Return ResourceManager.GetString("PPG_Reference_FailedToUpdateWebReference", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Adding or removing &apos;{0}&apos; as a project import failed because of an unexpected error from the project system.  The error returned was:  &apos;{1}&apos;..
        '''</summary>
        Friend Shared ReadOnly Property PPG_Reference_RemoveImportsFailUnexpected() As String
            Get
                Return ResourceManager.GetString("PPG_Reference_RemoveImportsFailUnexpected", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Reference Properties.
        '''</summary>
        Friend Shared ReadOnly Property PPG_ReferenceDetail_Title() As String
            Get
                Return ResourceManager.GetString("PPG_ReferenceDetail_Title", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Reference Paths.
        '''</summary>
        Friend Shared ReadOnly Property PPG_ReferencePaths_Title() As String
            Get
                Return ResourceManager.GetString("PPG_ReferencePaths_Title", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Reference Paths.
        '''</summary>
        Friend Shared ReadOnly Property PPG_ReferencePathsTitle() As String
            Get
                Return ResourceManager.GetString("PPG_ReferencePathsTitle", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to References.
        '''</summary>
        Friend Shared ReadOnly Property PPG_ReferencesTitle() As String
            Get
                Return ResourceManager.GetString("PPG_ReferencesTitle", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Security.
        '''</summary>
        Friend Shared ReadOnly Property PPG_Security() As String
            Get
                Return ResourceManager.GetString("PPG_Security", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Advanced Security Settings.
        '''</summary>
        Friend Shared ReadOnly Property PPG_SecurityAdvancedPage_Title() As String
            Get
                Return ResourceManager.GetString("PPG_SecurityAdvancedPage_Title", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Invalid value.
        '''</summary>
        Friend Shared ReadOnly Property PPG_SecurityPage_BadDropDownValue() As String
            Get
                Return ResourceManager.GetString("PPG_SecurityPage_BadDropDownValue", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to This permission could not be loaded. Press the delete key to remove it from your project..
        '''</summary>
        Friend Shared ReadOnly Property PPG_SecurityPage_BadPermissionToolTip() As String
            Get
                Return ResourceManager.GetString("PPG_SecurityPage_BadPermissionToolTip", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Included with warning.
        '''</summary>
        Friend Shared ReadOnly Property PPG_SecurityPage_BangAccessibilityName() As String
            Get
                Return ResourceManager.GetString("PPG_SecurityPage_BangAccessibilityName", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Not Included.
        '''</summary>
        Friend Shared ReadOnly Property PPG_SecurityPage_BlankAccessibilityName() As String
            Get
                Return ResourceManager.GetString("PPG_SecurityPage_BlankAccessibilityName", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to &amp;Calculate Permissions.
        '''</summary>
        Friend Shared ReadOnly Property PPG_SecurityPage_Calculate() As String
            Get
                Return ResourceManager.GetString("PPG_SecurityPage_Calculate", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Cancel.
        '''</summary>
        Friend Shared ReadOnly Property PPG_SecurityPage_Cancel() As String
            Get
                Return ResourceManager.GetString("PPG_SecurityPage_Cancel", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Included.
        '''</summary>
        Friend Shared ReadOnly Property PPG_SecurityPage_CheckAccessibilityName() As String
            Get
                Return ResourceManager.GetString("PPG_SecurityPage_CheckAccessibilityName", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to An error occurred and the app.manifest file could not be loaded. Please remove any changes you have made to the file and reload the Security property page again..
        '''</summary>
        Friend Shared ReadOnly Property PPG_SecurityPage_CouldNotLoadManifest() As String
            Get
                Return ResourceManager.GetString("PPG_SecurityPage_CouldNotLoadManifest", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to An error occurred and the app.manifest file could not be saved.
        '''Error:.
        '''</summary>
        Friend Shared ReadOnly Property PPG_SecurityPage_CouldNotSaveManifest() As String
            Get
                Return ResourceManager.GetString("PPG_SecurityPage_CouldNotSaveManifest", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to (Custom).
        '''</summary>
        Friend Shared ReadOnly Property PPG_SecurityPage_CustomZone() As String
            Get
                Return ResourceManager.GetString("PPG_SecurityPage_CustomZone", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Exclude.
        '''</summary>
        Friend Shared ReadOnly Property PPG_SecurityPage_Excluded() As String
            Get
                Return ResourceManager.GetString("PPG_SecurityPage_Excluded", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to The SecurityPermission must be included in your application with the Execute flag set or your application will not run. The Execute flag has been added to the SecurityPermission in your manifest..
        '''</summary>
        Friend Shared ReadOnly Property PPG_SecurityPage_ExecuteCannotBeExcluded() As String
            Get
                Return ResourceManager.GetString("PPG_SecurityPage_ExecuteCannotBeExcluded", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to The application will require elevated permissions to run in the selected zone. Click the help link above for more info..
        '''</summary>
        Friend Shared ReadOnly Property PPG_SecurityPage_FullTrustToolTip() As String
            Get
                Return ResourceManager.GetString("PPG_SecurityPage_FullTrustToolTip", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Included.
        '''</summary>
        Friend Shared ReadOnly Property PPG_SecurityPage_HeaderIncluded() As String
            Get
                Return ResourceManager.GetString("PPG_SecurityPage_HeaderIncluded", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Permission.
        '''</summary>
        Friend Shared ReadOnly Property PPG_SecurityPage_HeaderPermission() As String
            Get
                Return ResourceManager.GetString("PPG_SecurityPage_HeaderPermission", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Setting.
        '''</summary>
        Friend Shared ReadOnly Property PPG_SecurityPage_HeaderSetting() As String
            Get
                Return ResourceManager.GetString("PPG_SecurityPage_HeaderSetting", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Learn more about code access security....
        '''</summary>
        Friend Shared ReadOnly Property PPG_SecurityPage_HelpLabelLink() As String
            Get
                Return ResourceManager.GetString("PPG_SecurityPage_HelpLabelLink", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Specify the code access security permissions that your ClickOnce application requires in order to run. Learn more about code access security....
        '''</summary>
        Friend Shared ReadOnly Property PPG_SecurityPage_HelpLabelText() As String
            Get
                Return ResourceManager.GetString("PPG_SecurityPage_HelpLabelText", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Include.
        '''</summary>
        Friend Shared ReadOnly Property PPG_SecurityPage_Included() As String
            Get
                Return ResourceManager.GetString("PPG_SecurityPage_Included", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Internet.
        '''</summary>
        Friend Shared ReadOnly Property PPG_SecurityPage_InternetZone() As String
            Get
                Return ResourceManager.GetString("PPG_SecurityPage_InternetZone", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Local Intranet.
        '''</summary>
        Friend Shared ReadOnly Property PPG_SecurityPage_LocalIntranetZone() As String
            Get
                Return ResourceManager.GetString("PPG_SecurityPage_LocalIntranetZone", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Calculating permissions failed..
        '''</summary>
        Friend Shared ReadOnly Property PPG_SecurityPage_PermCalcFailed() As String
            Get
                Return ResourceManager.GetString("PPG_SecurityPage_PermCalcFailed", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Error.
        '''</summary>
        Friend Shared ReadOnly Property PPG_SecurityPage_PermCalcFailedCaption() As String
            Get
                Return ResourceManager.GetString("PPG_SecurityPage_PermCalcFailedCaption", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to The SecurityPermission must be included in your application with the Execute flag set or your application will not run. Mark this permission as &quot;Zone Default&quot; or &quot;Include.&quot;.
        '''</summary>
        Friend Shared ReadOnly Property PPG_SecurityPage_SecurityPermissionCannotBeExcluded() As String
            Get
                Return ResourceManager.GetString("PPG_SecurityPage_SecurityPermissionCannotBeExcluded", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to This application requires full trust to run correctly. Would you like to set this as a full trust application?.
        '''</summary>
        Friend Shared ReadOnly Property PPG_SecurityPage_SwitchToFullTrustDialog() As String
            Get
                Return ResourceManager.GetString("PPG_SecurityPage_SwitchToFullTrustDialog", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Full Trust Required.
        '''</summary>
        Friend Shared ReadOnly Property PPG_SecurityPage_SwitchToFullTrustDialogTitle() As String
            Get
                Return ResourceManager.GetString("PPG_SecurityPage_SwitchToFullTrustDialogTitle", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to The application will fail to run in the selected zone because of this requested elevated permission. Click the help link above for more info..
        '''</summary>
        Friend Shared ReadOnly Property PPG_SecurityPage_XBAPOutOfTrustZoneToolTip() As String
            Get
                Return ResourceManager.GetString("PPG_SecurityPage_XBAPOutOfTrustZoneToolTip", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to (Zone Default).
        '''</summary>
        Friend Shared ReadOnly Property PPG_SecurityPage_ZoneDefault() As String
            Get
                Return ResourceManager.GetString("PPG_SecurityPage_ZoneDefault", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Select File.
        '''</summary>
        Friend Shared ReadOnly Property PPG_SelectFileTitle() As String
            Get
                Return ResourceManager.GetString("PPG_SelectFileTitle", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Select Output Path.
        '''</summary>
        Friend Shared ReadOnly Property PPG_SelectOutputPathTitle() As String
            Get
                Return ResourceManager.GetString("PPG_SelectOutputPathTitle", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Select Reference Path.
        '''</summary>
        Friend Shared ReadOnly Property PPG_SelectReferencePath() As String
            Get
                Return ResourceManager.GetString("PPG_SelectReferencePath", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Select Working Directory.
        '''</summary>
        Friend Shared ReadOnly Property PPG_SelectWorkingDirectoryTitle() As String
            Get
                Return ResourceManager.GetString("PPG_SelectWorkingDirectoryTitle", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Namespace of the service reference..
        '''</summary>
        Friend Shared ReadOnly Property PPG_ServiceReferenceNamespaceDescription() As String
            Get
                Return ResourceManager.GetString("PPG_ServiceReferenceNamespaceDescription", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to A service reference with multiple source urls is not supported..
        '''</summary>
        Friend Shared ReadOnly Property PPG_ServiceReferenceProperty_MultipleUrlNotSupported() As String
            Get
                Return ResourceManager.GetString("PPG_ServiceReferenceProperty_MultipleUrlNotSupported", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Cannot change reference Url to empty. The reference url must be a valid URL..
        '''</summary>
        Friend Shared ReadOnly Property PPG_ServiceReferenceProperty_SetReferenceUrlEmpty() As String
            Get
                Return ResourceManager.GetString("PPG_ServiceReferenceProperty_SetReferenceUrlEmpty", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Service Reference Properties.
        '''</summary>
        Friend Shared ReadOnly Property PPG_ServiceReferenceTypeName() As String
            Get
                Return ResourceManager.GetString("PPG_ServiceReferenceTypeName", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Metadata Location Url.
        '''</summary>
        Friend Shared ReadOnly Property PPG_ServiceReferenceUrlDescription() As String
            Get
                Return ResourceManager.GetString("PPG_ServiceReferenceUrlDescription", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Metadata Location.
        '''</summary>
        Friend Shared ReadOnly Property PPG_ServiceReferenceUrlName() As String
            Get
                Return ResourceManager.GetString("PPG_ServiceReferenceUrlName", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Services.
        '''</summary>
        Friend Shared ReadOnly Property PPG_Services() As String
            Get
                Return ResourceManager.GetString("PPG_Services", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Disabling application services will clear the default services for Authentication, Roles, and Settings.  Click OK to disable application services..
        '''</summary>
        Friend Shared ReadOnly Property PPG_Services_ConfirmRemoveServices() As String
            Get
                Return ResourceManager.GetString("PPG_Services_ConfirmRemoveServices", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Disable Application Services.
        '''</summary>
        Friend Shared ReadOnly Property PPG_Services_ConfirmRemoveServices_Caption() As String
            Get
                Return ResourceManager.GetString("PPG_Services_ConfirmRemoveServices_Caption", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Authentication, Roles and Web Settings providers have been configured via the Application configuration file such that they do not share a common connection string..
        '''</summary>
        Friend Shared ReadOnly Property PPG_Services_ConnectionStringsDontMatch() As String
            Get
                Return ResourceManager.GetString("PPG_Services_ConnectionStringsDontMatch", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Specify a connection string to a SQL Server database, or use the special connection string &quot;Data Source = |SQL/CE|&quot;, which causes SQL Server Compact Edition to generate local database files for offline storage..
        '''</summary>
        Friend Shared ReadOnly Property PPG_Services_connectionStringValueDefaultDisplayValue() As String
            Get
                Return ResourceManager.GetString("PPG_Services_connectionStringValueDefaultDisplayValue", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to days.
        '''</summary>
        Friend Shared ReadOnly Property PPG_Services_Days() As String
            Get
                Return ResourceManager.GetString("PPG_Services_Days", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Learn more about client application services....
        '''</summary>
        Friend Shared ReadOnly Property PPG_Services_HelpLabelLink() As String
            Get
                Return ResourceManager.GetString("PPG_Services_HelpLabelLink", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Client application services enable your Windows-based applications to use the ASP.NET login (authentication), roles, and profile (settings) services.  .
        '''</summary>
        Friend Shared ReadOnly Property PPG_Services_HelpLabelText() As String
            Get
                Return ResourceManager.GetString("PPG_Services_HelpLabelText", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to hours.
        '''</summary>
        Friend Shared ReadOnly Property PPG_Services_Hours() As String
            Get
                Return ResourceManager.GetString("PPG_Services_Hours", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to An error occurred while reading the Application configuration file.  The file might be corrupted or contain invalid XML..
        '''</summary>
        Friend Shared ReadOnly Property PPG_Services_InvalidAppConfigXml() As String
            Get
                Return ResourceManager.GetString("PPG_Services_InvalidAppConfigXml", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to The URL is invalid. Please enter a valid URL like http://microsoft.com/services.
        '''</summary>
        Friend Shared ReadOnly Property PPG_Services_InvalidUrl() As String
            Get
                Return ResourceManager.GetString("PPG_Services_InvalidUrl", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to A service URL in the application configuration file is not in the expected format..
        '''</summary>
        Friend Shared ReadOnly Property PPG_Services_InvalidUrls() As String
            Get
                Return ResourceManager.GetString("PPG_Services_InvalidUrls", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to minutes.
        '''</summary>
        Friend Shared ReadOnly Property PPG_Services_Minutes() As String
            Get
                Return ResourceManager.GetString("PPG_Services_Minutes", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to seconds.
        '''</summary>
        Friend Shared ReadOnly Property PPG_Services_Seconds() As String
            Get
                Return ResourceManager.GetString("PPG_Services_Seconds", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Advanced Settings for Services.
        '''</summary>
        Friend Shared ReadOnly Property PPG_ServicesAdvancedPage_Title() As String
            Get
                Return ResourceManager.GetString("PPG_ServicesAdvancedPage_Title", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to &lt;All&gt;.
        '''</summary>
        Friend Shared ReadOnly Property PPG_Signing_AllPurposes() As String
            Get
                Return ResourceManager.GetString("PPG_Signing_AllPurposes", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Certificate Files.
        '''</summary>
        Friend Shared ReadOnly Property PPG_Signing_BrowseCertFileFilter() As String
            Get
                Return ResourceManager.GetString("PPG_Signing_BrowseCertFileFilter", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Select a certificate to sign your ClickOnce manifests.
        '''</summary>
        Friend Shared ReadOnly Property PPG_Signing_BrowseCertStorePrompt() As String
            Get
                Return ResourceManager.GetString("PPG_Signing_BrowseCertStorePrompt", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Select a Certificate.
        '''</summary>
        Friend Shared ReadOnly Property PPG_Signing_BrowseCertTitle() As String
            Get
                Return ResourceManager.GetString("PPG_Signing_BrowseCertTitle", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Certificate Creation Error.
        '''</summary>
        Friend Shared ReadOnly Property PPG_Signing_CertCreationError() As String
            Get
                Return ResourceManager.GetString("PPG_Signing_CertCreationError", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to The selected certificate is not valid for code signing. Choose another certificate file..
        '''</summary>
        Friend Shared ReadOnly Property PPG_Signing_CertificateNotCodeSigning() As String
            Get
                Return ResourceManager.GetString("PPG_Signing_CertificateNotCodeSigning", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to The file &apos;{0}&apos; could not be imported: {1}.
        '''</summary>
        Friend Shared ReadOnly Property PPG_Signing_CouldNotImportFile() As String
            Get
                Return ResourceManager.GetString("PPG_Signing_CouldNotImportFile", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Enter &amp;password for new file {0}.
        '''</summary>
        Friend Shared ReadOnly Property PPG_Signing_CreateNewKeyPasswordPrompt() As String
            Get
                Return ResourceManager.GetString("PPG_Signing_CreateNewKeyPasswordPrompt", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Expiration Date.
        '''</summary>
        Friend Shared ReadOnly Property PPG_Signing_ExpirationDate() As String
            Get
                Return ResourceManager.GetString("PPG_Signing_ExpirationDate", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to The password is invalid..
        '''</summary>
        Friend Shared ReadOnly Property PPG_Signing_InvalidPassword() As String
            Get
                Return ResourceManager.GetString("PPG_Signing_InvalidPassword", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Invalid password.
        '''</summary>
        Friend Shared ReadOnly Property PPG_Signing_InvalidPasswordTitle() As String
            Get
                Return ResourceManager.GetString("PPG_Signing_InvalidPasswordTitle", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Issued By.
        '''</summary>
        Friend Shared ReadOnly Property PPG_Signing_IssuedBy() As String
            Get
                Return ResourceManager.GetString("PPG_Signing_IssuedBy", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Issued To.
        '''</summary>
        Friend Shared ReadOnly Property PPG_Signing_IssuedTo() As String
            Get
                Return ResourceManager.GetString("PPG_Signing_IssuedTo", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Key Files.
        '''</summary>
        Friend Shared ReadOnly Property PPG_Signing_KeyFileBrowse_Filter() As String
            Get
                Return ResourceManager.GetString("PPG_Signing_KeyFileBrowse_Filter", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Selecting existing key file.
        '''</summary>
        Friend Shared ReadOnly Property PPG_Signing_KeyFileBrowse_Title() As String
            Get
                Return ResourceManager.GetString("PPG_Signing_KeyFileBrowse_Title", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to _TemporaryKey.pfx.
        '''</summary>
        Friend Shared ReadOnly Property PPG_Signing_KeyFileNameSuffix() As String
            Get
                Return ResourceManager.GetString("PPG_Signing_KeyFileNameSuffix", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Create key file.
        '''</summary>
        Friend Shared ReadOnly Property PPG_Signing_KeyFileNew_Title() As String
            Get
                Return ResourceManager.GetString("PPG_Signing_KeyFileNew_Title", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Enter a new password..
        '''</summary>
        Friend Shared ReadOnly Property PPG_Signing_NewPassEmpty() As String
            Get
                Return ResourceManager.GetString("PPG_Signing_NewPassEmpty", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to The new passwords do not match. Enter the password again..
        '''</summary>
        Friend Shared ReadOnly Property PPG_Signing_NewPassMismatch() As String
            Get
                Return ResourceManager.GetString("PPG_Signing_NewPassMismatch", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to The new password must be at least 6 characters in length. Enter the password again..
        '''</summary>
        Friend Shared ReadOnly Property PPG_Signing_NewPassTooShort() As String
            Get
                Return ResourceManager.GetString("PPG_Signing_NewPassTooShort", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Confirm the password..
        '''</summary>
        Friend Shared ReadOnly Property PPG_Signing_NoConfirm() As String
            Get
                Return ResourceManager.GetString("PPG_Signing_NoConfirm", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to (none).
        '''</summary>
        Friend Shared ReadOnly Property PPG_Signing_NoData() As String
            Get
                Return ResourceManager.GetString("PPG_Signing_NoData", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Enter a password..
        '''</summary>
        Friend Shared ReadOnly Property PPG_Signing_NoPassword() As String
            Get
                Return ResourceManager.GetString("PPG_Signing_NoPassword", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to The selected file does not contain a private key. You must choose a certificate that contains a private key..
        '''</summary>
        Friend Shared ReadOnly Property PPG_Signing_NoPrivateKey() As String
            Get
                Return ResourceManager.GetString("PPG_Signing_NoPrivateKey", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Invalid key.
        '''</summary>
        Friend Shared ReadOnly Property PPG_Signing_NoPrivateKeyTitle() As String
            Get
                Return ResourceManager.GetString("PPG_Signing_NoPrivateKeyTitle", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Enter the old password..
        '''</summary>
        Friend Shared ReadOnly Property PPG_Signing_OldPassEmpty() As String
            Get
                Return ResourceManager.GetString("PPG_Signing_OldPassEmpty", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to The old password is invalid..
        '''</summary>
        Friend Shared ReadOnly Property PPG_Signing_OldPassWrong() As String
            Get
                Return ResourceManager.GetString("PPG_Signing_OldPassWrong", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Enter &amp;password to open file {0}.
        '''</summary>
        Friend Shared ReadOnly Property PPG_Signing_OpenExistingKeyPasswordPrompt() As String
            Get
                Return ResourceManager.GetString("PPG_Signing_OpenExistingKeyPasswordPrompt", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Enter password to open file.
        '''</summary>
        Friend Shared ReadOnly Property PPG_Signing_OpenExistingKeyPasswordTitle() As String
            Get
                Return ResourceManager.GetString("PPG_Signing_OpenExistingKeyPasswordTitle", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to The passwords do not match..
        '''</summary>
        Friend Shared ReadOnly Property PPG_Signing_PasswordMismatch() As String
            Get
                Return ResourceManager.GetString("PPG_Signing_PasswordMismatch", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to The project already contains a file with that name. Choose another certificate file or rename the file in your project..
        '''</summary>
        Friend Shared ReadOnly Property PPG_Signing_ProjectAlreadyContainsFile() As String
            Get
                Return ResourceManager.GetString("PPG_Signing_ProjectAlreadyContainsFile", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Intended Purpose.
        '''</summary>
        Friend Shared ReadOnly Property PPG_Signing_Purpose() As String
            Get
                Return ResourceManager.GetString("PPG_Signing_Purpose", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Signing.
        '''</summary>
        Friend Shared ReadOnly Property PPG_SigningTitle() As String
            Get
                Return ResourceManager.GetString("PPG_SigningTitle", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to (None).
        '''</summary>
        Friend Shared ReadOnly Property PPG_StartupObjectNone() As String
            Get
                Return ResourceManager.GetString("PPG_StartupObjectNone", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Change property: {0}.
        '''</summary>
        Friend Shared ReadOnly Property PPG_UndoTransaction() As String
            Get
                Return ResourceManager.GetString("PPG_UndoTransaction", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to An unspecified error has occurred..
        '''</summary>
        Friend Shared ReadOnly Property PPG_Unexpected() As String
            Get
                Return ResourceManager.GetString("PPG_Unexpected", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Dynamic.
        '''</summary>
        Friend Shared ReadOnly Property PPG_UrlBehavior_Dynamic() As String
            Get
                Return ResourceManager.GetString("PPG_UrlBehavior_Dynamic", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Static.
        '''</summary>
        Friend Shared ReadOnly Property PPG_UrlBehavior_Static() As String
            Get
                Return ResourceManager.GetString("PPG_UrlBehavior_Static", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Web reference URL behavior.
        '''</summary>
        Friend Shared ReadOnly Property PPG_UrlBehaviorDescription() As String
            Get
                Return ResourceManager.GetString("PPG_UrlBehaviorDescription", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to URL Behavior.
        '''</summary>
        Friend Shared ReadOnly Property PPG_UrlBehaviorName() As String
            Get
                Return ResourceManager.GetString("PPG_UrlBehaviorName", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Database.
        '''</summary>
        Friend Shared ReadOnly Property PPG_VdtGeneralTitle() As String
            Get
                Return ResourceManager.GetString("PPG_VdtGeneralTitle", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Version.
        '''</summary>
        Friend Shared ReadOnly Property PPG_VersionTitle() As String
            Get
                Return ResourceManager.GetString("PPG_VersionTitle", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Web Control Library.
        '''</summary>
        Friend Shared ReadOnly Property PPG_WebControlLib() As String
            Get
                Return ResourceManager.GetString("PPG_WebControlLib", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Name of the web reference.
        '''</summary>
        Friend Shared ReadOnly Property PPG_WebReferenceNameDescription() As String
            Get
                Return ResourceManager.GetString("PPG_WebReferenceNameDescription", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Web Reference Properties.
        '''</summary>
        Friend Shared ReadOnly Property PPG_WebReferenceTypeName() As String
            Get
                Return ResourceManager.GetString("PPG_WebReferenceTypeName", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Web Reference URL.
        '''</summary>
        Friend Shared ReadOnly Property PPG_WebReferenceUrlDescription() As String
            Get
                Return ResourceManager.GetString("PPG_WebReferenceUrlDescription", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Web Reference URL.
        '''</summary>
        Friend Shared ReadOnly Property PPG_WebReferenceUrlName() As String
            Get
                Return ResourceManager.GetString("PPG_WebReferenceUrlName", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Windows Application.
        '''</summary>
        Friend Shared ReadOnly Property PPG_WindowsApp() As String
            Get
                Return ResourceManager.GetString("PPG_WindowsApp", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to WPF Application.
        '''</summary>
        Friend Shared ReadOnly Property PPG_WindowsApp_WPF() As String
            Get
                Return ResourceManager.GetString("PPG_WindowsApp_WPF", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Class Library.
        '''</summary>
        Friend Shared ReadOnly Property PPG_WindowsClassLib() As String
            Get
                Return ResourceManager.GetString("PPG_WindowsClassLib", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to WPF Class Library.
        '''</summary>
        Friend Shared ReadOnly Property PPG_WindowsClassLib_WPF() As String
            Get
                Return ResourceManager.GetString("PPG_WindowsClassLib_WPF", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Windows Forms Application.
        '''</summary>
        Friend Shared ReadOnly Property PPG_WindowsFormsApp() As String
            Get
                Return ResourceManager.GetString("PPG_WindowsFormsApp", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Windows Service.
        '''</summary>
        Friend Shared ReadOnly Property PPG_WindowsService() As String
            Get
                Return ResourceManager.GetString("PPG_WindowsService", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to The application definition file is already opened in an incompatible editor.  Please close the other editor and reload the project properties page..
        '''</summary>
        Friend Shared ReadOnly Property PPG_WPFApp_AppXamlOpenInUnsupportedEditor() As String
            Get
                Return ResourceManager.GetString("PPG_WPFApp_AppXamlOpenInUnsupportedEditor", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to This project does not contain an application definition file..
        '''</summary>
        Friend Shared ReadOnly Property PPG_WPFApp_CantFindAppXaml() As String
            Get
                Return ResourceManager.GetString("PPG_WPFApp_CantFindAppXaml", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to There was an error trying to open or create the application definition file for this project.  {0}.
        '''</summary>
        Friend Shared ReadOnly Property PPG_WPFApp_CantOpenOrCreateAppXaml_1Arg() As String
            Get
                Return ResourceManager.GetString("PPG_WPFApp_CantOpenOrCreateAppXaml_1Arg", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to (Error).
        '''</summary>
        Friend Shared ReadOnly Property PPG_WPFApp_CantReadPropertyValue() As String
            Get
                Return ResourceManager.GetString("PPG_WPFApp_CantReadPropertyValue", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to An error occurred trying to create the application events file.  {0}.
        '''</summary>
        Friend Shared ReadOnly Property PPG_WPFApp_CouldntCreateApplicationEventsFile_1Arg() As String
            Get
                Return ResourceManager.GetString("PPG_WPFApp_CouldntCreateApplicationEventsFile_1Arg", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to An error occurred trying to load the application definition file for this project.  The file &apos;{0}&apos; could not be parsed.  Please edit the file in the XAML editor to fix the error..
        '''</summary>
        Friend Shared ReadOnly Property PPG_WPFApp_ErrorControlMessage_1Arg() As String
            Get
                Return ResourceManager.GetString("PPG_WPFApp_ErrorControlMessage_1Arg", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to (Invalid value: &quot;{0}&quot;).
        '''</summary>
        Friend Shared ReadOnly Property PPG_WPFApp_InvalidShutdownMode() As String
            Get
                Return ResourceManager.GetString("PPG_WPFApp_InvalidShutdownMode", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to On explicit shutdown.
        '''</summary>
        Friend Shared ReadOnly Property PPG_WPFApp_ShutdownMode_OnExplicitShutdown() As String
            Get
                Return ResourceManager.GetString("PPG_WPFApp_ShutdownMode_OnExplicitShutdown", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to On last window close.
        '''</summary>
        Friend Shared ReadOnly Property PPG_WPFApp_ShutdownMode_OnLastWindowClose() As String
            Get
                Return ResourceManager.GetString("PPG_WPFApp_ShutdownMode_OnLastWindowClose", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to On main window close.
        '''</summary>
        Friend Shared ReadOnly Property PPG_WPFApp_ShutdownMode_OnMainWindowClose() As String
            Get
                Return ResourceManager.GetString("PPG_WPFApp_ShutdownMode_OnMainWindowClose", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Could not find the expected root element &quot;{0}&quot; in the application definition file..
        '''</summary>
        Friend Shared ReadOnly Property PPG_WPFApp_Xaml_CouldntFindRootElement() As String
            Get
                Return ResourceManager.GetString("PPG_WPFApp_Xaml_CouldntFindRootElement", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to The .xaml file was in an unexpected format, near line {0} column {1}..
        '''</summary>
        Friend Shared ReadOnly Property PPG_WPFApp_Xaml_UnexpectedFormat_2Args() As String
            Get
                Return ResourceManager.GetString("PPG_WPFApp_Xaml_UnexpectedFormat_2Args", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to The URL is invalid. Please enter a valid URL like &quot;http://www.microsoft.com/&quot;.
        '''</summary>
        Friend Shared ReadOnly Property PropPage_InvalidURL() As String
            Get
                Return ResourceManager.GetString("PropPage_InvalidURL", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to The external program property cannot be empty. Please enter a valid executable file..
        '''</summary>
        Friend Shared ReadOnly Property PropPage_NeedExternalProgram() As String
            Get
                Return ResourceManager.GetString("PropPage_NeedExternalProgram", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to &quot;Resource files must have a .res file extension. Please enter a valid resource file name.&quot;.
        '''</summary>
        Friend Shared ReadOnly Property PropPage_NeedResFile() As String
            Get
                Return ResourceManager.GetString("PropPage_NeedResFile", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to The URL property cannot be empty. Please enter a valid URL..
        '''</summary>
        Friend Shared ReadOnly Property PropPage_NeedURL() As String
            Get
                Return ResourceManager.GetString("PropPage_NeedURL", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to We can only debug an EXE file. Please enter a valid executable file..
        '''</summary>
        Friend Shared ReadOnly Property PropPage_NotAnExeError() As String
            Get
                Return ResourceManager.GetString("PropPage_NotAnExeError", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to The external program cannot be found. Please enter a valid executable file..
        '''</summary>
        Friend Shared ReadOnly Property PropPage_ProgramNonexistent() As String
            Get
                Return ResourceManager.GetString("PropPage_ProgramNonexistent", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to &lt;The system cannot find the reference specified&gt;.
        '''</summary>
        Friend Shared ReadOnly Property PropPage_ReferenceNotFound() As String
            Get
                Return ResourceManager.GetString("PropPage_ReferenceNotFound", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to The remote machine name cannot be blank.  Please specify the name of the machine to debug remotely..
        '''</summary>
        Friend Shared ReadOnly Property PropPage_RemoteMachineBlankError() As String
            Get
                Return ResourceManager.GetString("PropPage_RemoteMachineBlankError", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to &quot;The resource file entered does not exist.&quot;.
        '''</summary>
        Friend Shared ReadOnly Property PropPage_ResourceFileNonexistent() As String
            Get
                Return ResourceManager.GetString("PropPage_ResourceFileNonexistent", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Project compilation failed. Cannot determine unused references..
        '''</summary>
        Friend Shared ReadOnly Property PropPage_UnusedReferenceCompileFail() As String
            Get
                Return ResourceManager.GetString("PropPage_UnusedReferenceCompileFail", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Gathering list of unused references....
        '''</summary>
        Friend Shared ReadOnly Property PropPage_UnusedReferenceCompileWaiting() As String
            Get
                Return ResourceManager.GetString("PropPage_UnusedReferenceCompileWaiting", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Error getting unused references..
        '''</summary>
        Friend Shared ReadOnly Property PropPage_UnusedReferenceError() As String
            Get
                Return ResourceManager.GetString("PropPage_UnusedReferenceError", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to No unused references.
        '''</summary>
        Friend Shared ReadOnly Property PropPage_UnusedReferenceNoUnusedReferences() As String
            Get
                Return ResourceManager.GetString("PropPage_UnusedReferenceNoUnusedReferences", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to &amp;Remove.
        '''</summary>
        Friend Shared ReadOnly Property PropPage_UnusedReferenceRemoveButton() As String
            Get
                Return ResourceManager.GetString("PropPage_UnusedReferenceRemoveButton", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Unused References.
        '''</summary>
        Friend Shared ReadOnly Property PropPage_UnusedReferenceTitle() As String
            Get
                Return ResourceManager.GetString("PropPage_UnusedReferenceTitle", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to The working directory you entered does not exist. Please enter a valid working directory..
        '''</summary>
        Friend Shared ReadOnly Property PropPage_WorkingDirError() As String
            Get
                Return ResourceManager.GetString("PropPage_WorkingDirError", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Embedded in .resx.
        '''</summary>
        Friend Shared ReadOnly Property RES_PersistenceMode_Embedded() As String
            Get
                Return ResourceManager.GetString("RES_PersistenceMode_Embedded", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Linked at compile time.
        '''</summary>
        Friend Shared ReadOnly Property RES_PersistenceMode_Linked() As String
            Get
                Return ResourceManager.GetString("RES_PersistenceMode_Linked", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Unable to add &apos;{0}&apos; to the project..
        '''</summary>
        Friend Shared ReadOnly Property RFS_CantAddFileToProject_File() As String
            Get
                Return ResourceManager.GetString("RFS_CantAddFileToProject_File", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Unable to add &apos;{0}&apos; to the project.
        '''
        '''{1}.
        '''</summary>
        Friend Shared ReadOnly Property RFS_CantAddFileToProject_File_ExMsg() As String
            Get
                Return ResourceManager.GetString("RFS_CantAddFileToProject_File_ExMsg", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Unable to add a &apos;{0}&apos; folder to this project.
        '''
        '''{1}.
        '''</summary>
        Friend Shared ReadOnly Property RFS_CantCreateResourcesFolder_Folder_ExMsg() As String
            Get
                Return ResourceManager.GetString("RFS_CantCreateResourcesFolder_Folder_ExMsg", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Cannot find the file &apos;{0}&apos;.  It may have been moved or deleted..
        '''</summary>
        Friend Shared ReadOnly Property RFS_FindNotFound_File() As String
            Get
                Return ResourceManager.GetString("RFS_FindNotFound_File", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to There is already a linked file with the name &quot;{0}&quot; in the project folder &quot;{1}&quot;.  Do you want to remove it?.
        '''</summary>
        Friend Shared ReadOnly Property RFS_QueryRemoveLink_Folder_Link() As String
            Get
                Return ResourceManager.GetString("RFS_QueryRemoveLink_Folder_Link", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to {0} - Destination File Exists.
        '''</summary>
        Friend Shared ReadOnly Property RFS_QueryRemoveLinkTitle_Editor() As String
            Get
                Return ResourceManager.GetString("RFS_QueryRemoveLinkTitle_Editor", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to A file with the name &apos;{0}&apos; already exists.  Do you want to replace it?.
        '''</summary>
        Friend Shared ReadOnly Property RFS_QueryReplaceFile_File() As String
            Get
                Return ResourceManager.GetString("RFS_QueryReplaceFile_File", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to {0} - Destination File Exists.
        '''</summary>
        Friend Shared ReadOnly Property RFS_QueryReplaceFileTitle_Editor() As String
            Get
                Return ResourceManager.GetString("RFS_QueryReplaceFileTitle_Editor", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to (Custom).
        '''</summary>
        Friend Shared ReadOnly Property RSE_AccessModifier_Custom() As String
            Get
                Return ResourceManager.GetString("RSE_AccessModifier_Custom", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to &amp;Add.
        '''</summary>
        Friend Shared ReadOnly Property RSE_Btn_Add() As String
            Get
                Return ResourceManager.GetString("RSE_Btn_Add", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to &amp;Existing File....
        '''</summary>
        Friend Shared ReadOnly Property RSE_Btn_Add_ExistingFile() As String
            Get
                Return ResourceManager.GetString("RSE_Btn_Add_ExistingFile", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to New I&amp;con....
        '''</summary>
        Friend Shared ReadOnly Property RSE_Btn_Add_Icon() As String
            Get
                Return ResourceManager.GetString("RSE_Btn_Add_Icon", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to New &amp;Image.
        '''</summary>
        Friend Shared ReadOnly Property RSE_Btn_Add_Image() As String
            Get
                Return ResourceManager.GetString("RSE_Btn_Add_Image", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to &amp;BMP Image....
        '''</summary>
        Friend Shared ReadOnly Property RSE_Btn_Add_Image_BMP() As String
            Get
                Return ResourceManager.GetString("RSE_Btn_Add_Image_BMP", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to &amp;GIF Image....
        '''</summary>
        Friend Shared ReadOnly Property RSE_Btn_Add_Image_GIF() As String
            Get
                Return ResourceManager.GetString("RSE_Btn_Add_Image_GIF", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to &amp;JPEG Image....
        '''</summary>
        Friend Shared ReadOnly Property RSE_Btn_Add_Image_JPEG() As String
            Get
                Return ResourceManager.GetString("RSE_Btn_Add_Image_JPEG", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to &amp;PNG Image....
        '''</summary>
        Friend Shared ReadOnly Property RSE_Btn_Add_Image_PNG() As String
            Get
                Return ResourceManager.GetString("RSE_Btn_Add_Image_PNG", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to &amp;TIFF Image....
        '''</summary>
        Friend Shared ReadOnly Property RSE_Btn_Add_Image_TIFF() As String
            Get
                Return ResourceManager.GetString("RSE_Btn_Add_Image_TIFF", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to New &amp;String.
        '''</summary>
        Friend Shared ReadOnly Property RSE_Btn_Add_String() As String
            Get
                Return ResourceManager.GetString("RSE_Btn_Add_String", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to New &amp;Text File....
        '''</summary>
        Friend Shared ReadOnly Property RSE_Btn_Add_TextFile() As String
            Get
                Return ResourceManager.GetString("RSE_Btn_Add_TextFile", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to &amp;Remove.
        '''</summary>
        Friend Shared ReadOnly Property RSE_Btn_Remove() As String
            Get
                Return ResourceManager.GetString("RSE_Btn_Remove", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to &amp;Views.
        '''</summary>
        Friend Shared ReadOnly Property RSE_Btn_Views() As String
            Get
                Return ResourceManager.GetString("RSE_Btn_Views", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to &amp;Details.
        '''</summary>
        Friend Shared ReadOnly Property RSE_Btn_Views_Details() As String
            Get
                Return ResourceManager.GetString("RSE_Btn_Views_Details", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to &amp;List.
        '''</summary>
        Friend Shared ReadOnly Property RSE_Btn_Views_List() As String
            Get
                Return ResourceManager.GetString("RSE_Btn_Views_List", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to &amp;Thumbnail.
        '''</summary>
        Friend Shared ReadOnly Property RSE_Btn_Views_Thumbnail() As String
            Get
                Return ResourceManager.GetString("RSE_Btn_Views_Thumbnail", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Audio.
        '''</summary>
        Friend Shared ReadOnly Property RSE_Cat_Audio() As String
            Get
                Return ResourceManager.GetString("RSE_Cat_Audio", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Files.
        '''</summary>
        Friend Shared ReadOnly Property RSE_Cat_Files() As String
            Get
                Return ResourceManager.GetString("RSE_Cat_Files", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Icons.
        '''</summary>
        Friend Shared ReadOnly Property RSE_Cat_Icons() As String
            Get
                Return ResourceManager.GetString("RSE_Cat_Icons", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Images.
        '''</summary>
        Friend Shared ReadOnly Property RSE_Cat_Images() As String
            Get
                Return ResourceManager.GetString("RSE_Cat_Images", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Other.
        '''</summary>
        Friend Shared ReadOnly Property RSE_Cat_Other() As String
            Get
                Return ResourceManager.GetString("RSE_Cat_Other", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Strings.
        '''</summary>
        Friend Shared ReadOnly Property RSE_Cat_Strings() As String
            Get
                Return ResourceManager.GetString("RSE_Cat_Strings", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to &amp;Categories:.
        '''</summary>
        Friend Shared ReadOnly Property RSE_CategoriesLabel() As String
            Get
                Return ResourceManager.GetString("RSE_CategoriesLabel", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Comment.
        '''</summary>
        Friend Shared ReadOnly Property RSE_CommentColumn() As String
            Get
                Return ResourceManager.GetString("RSE_CommentColumn", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to (Default).
        '''</summary>
        Friend Shared ReadOnly Property RSE_DefaultEncoding() As String
            Get
                Return ResourceManager.GetString("RSE_DefaultEncoding", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Comment.
        '''</summary>
        Friend Shared ReadOnly Property RSE_DetailsCol_Comment() As String
            Get
                Return ResourceManager.GetString("RSE_DetailsCol_Comment", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Text Encoding.
        '''</summary>
        Friend Shared ReadOnly Property RSE_DetailsCol_Encoding() As String
            Get
                Return ResourceManager.GetString("RSE_DetailsCol_Encoding", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Filename.
        '''</summary>
        Friend Shared ReadOnly Property RSE_DetailsCol_Filename() As String
            Get
                Return ResourceManager.GetString("RSE_DetailsCol_Filename", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Type.
        '''</summary>
        Friend Shared ReadOnly Property RSE_DetailsCol_ImageType() As String
            Get
                Return ResourceManager.GetString("RSE_DetailsCol_ImageType", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Name.
        '''</summary>
        Friend Shared ReadOnly Property RSE_DetailsCol_Name() As String
            Get
                Return ResourceManager.GetString("RSE_DetailsCol_Name", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Size.
        '''</summary>
        Friend Shared ReadOnly Property RSE_DetailsCol_Size() As String
            Get
                Return ResourceManager.GetString("RSE_DetailsCol_Size", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Do you want to continue anyway?.
        '''</summary>
        Friend Shared ReadOnly Property RSE_Dlg_ContinueAnyway() As String
            Get
                Return ResourceManager.GetString("RSE_Dlg_ContinueAnyway", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Select a folder in which to export the resources..
        '''</summary>
        Friend Shared ReadOnly Property RSE_Dlg_ExportMultiple() As String
            Get
                Return ResourceManager.GetString("RSE_Dlg_ExportMultiple", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to The file &apos;{0}&apos; already exists.  Do you want to replace it?.
        '''</summary>
        Friend Shared ReadOnly Property RSE_Dlg_ReplaceExistingFile() As String
            Get
                Return ResourceManager.GetString("RSE_Dlg_ReplaceExistingFile", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to The following files already exist.  Do you want to replace them?.
        '''</summary>
        Friend Shared ReadOnly Property RSE_Dlg_ReplaceExistingFiles() As String
            Get
                Return ResourceManager.GetString("RSE_Dlg_ReplaceExistingFiles", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Do you want to enable strongly-typed resource generation for this file?.
        '''</summary>
        Friend Shared ReadOnly Property RSE_Dlg_SetCustomTool() As String
            Get
                Return ResourceManager.GetString("RSE_Dlg_SetCustomTool", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Add existing file to resources.
        '''</summary>
        Friend Shared ReadOnly Property RSE_DlgTitle_AddExisting() As String
            Get
                Return ResourceManager.GetString("RSE_DlgTitle_AddExisting", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Please specify where to save the new file.
        '''</summary>
        Friend Shared ReadOnly Property RSE_DlgTitle_AddNew() As String
            Get
                Return ResourceManager.GetString("RSE_DlgTitle_AddNew", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Export resource &apos;{0}&apos; to file.
        '''</summary>
        Friend Shared ReadOnly Property RSE_DlgTitle_Export_1Arg() As String
            Get
                Return ResourceManager.GetString("RSE_DlgTitle_Export_1Arg", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Import file into resource &apos;{0}&apos;.
        '''</summary>
        Friend Shared ReadOnly Property RSE_DlgTitle_Import_1Arg() As String
            Get
                Return ResourceManager.GetString("RSE_DlgTitle_Import_1Arg", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to {0} - Codepage {1}.
        '''</summary>
        Friend Shared ReadOnly Property RSE_EncodingDisplayName() As String
            Get
                Return ResourceManager.GetString("RSE_EncodingDisplayName", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to The resource value contains invalid data or has an incorrect format..
        '''</summary>
        Friend Shared ReadOnly Property RSE_Err_BadData() As String
            Get
                Return ResourceManager.GetString("RSE_Err_BadData", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to The name of the resource &apos;{0}&apos; cannot be used as a valid identifier, because it contains one or more invalid characters: &apos;{1}&apos;.  Please remove or replace those characters and try again..
        '''</summary>
        Friend Shared ReadOnly Property RSE_Err_BadIdentifier_2Arg() As String
            Get
                Return ResourceManager.GetString("RSE_Err_BadIdentifier_2Arg", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to The device does not support &apos;{0}&apos; files..
        '''</summary>
        Friend Shared ReadOnly Property RSE_Err_CantAddFileToDeviceProject_1Arg() As String
            Get
                Return ResourceManager.GetString("RSE_Err_CantAddFileToDeviceProject_1Arg", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to The resource &apos;{0}&apos; cannot be added..
        '''</summary>
        Friend Shared ReadOnly Property RSE_Err_CantAddUnsupportedResource_1Arg() As String
            Get
                Return ResourceManager.GetString("RSE_Err_CantAddUnsupportedResource_1Arg", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to One or more of the selected resource values could not be cleared..
        '''</summary>
        Friend Shared ReadOnly Property RSE_Err_CantBeEmpty() As String
            Get
                Return ResourceManager.GetString("RSE_Err_CantBeEmpty", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to The value could not be converted into a resource of type {0}.
        '''
        '''{1}.
        '''</summary>
        Friend Shared ReadOnly Property RSE_Err_CantConvertFromString_2Args() As String
            Get
                Return ResourceManager.GetString("RSE_Err_CantConvertFromString_2Args", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Unable to create new resource file &apos;{0}&apos;.  {1}.
        '''</summary>
        Friend Shared ReadOnly Property RSE_Err_CantCreateNewResource_2Args() As String
            Get
                Return ResourceManager.GetString("RSE_Err_CantCreateNewResource_2Args", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Editing embedded resources directly is not supported. Do you wish to convert this item to a linked resource in order to edit it?.
        '''</summary>
        Friend Shared ReadOnly Property RSE_Err_CantEditEmbeddedResource() As String
            Get
                Return ResourceManager.GetString("RSE_Err_CantEditEmbeddedResource", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to The resource file cannot be modified at this time..
        '''</summary>
        Friend Shared ReadOnly Property RSE_Err_CantEditInDebugMode() As String
            Get
                Return ResourceManager.GetString("RSE_Err_CantEditInDebugMode", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Cannot find the file &apos;{0}&apos;.  It may have been moved or deleted..
        '''</summary>
        Friend Shared ReadOnly Property RSE_Err_CantFindResourceFile_1Arg() As String
            Get
                Return ResourceManager.GetString("RSE_Err_CantFindResourceFile_1Arg", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Unable to play the audio resource.  {0}.
        '''</summary>
        Friend Shared ReadOnly Property RSE_Err_CantPlay_1Arg() As String
            Get
                Return ResourceManager.GetString("RSE_Err_CantPlay_1Arg", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to The resource item(s) {0} cannot be saved correctly.  The item(s) will be discarded..
        '''</summary>
        Friend Shared ReadOnly Property RSE_Err_CantSaveResourceDiscard_1Arg() As String
            Get
                Return ResourceManager.GetString("RSE_Err_CantSaveResourceDiscard_1Arg", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Resource &apos;{0}&apos; cannot be saved to a file..
        '''</summary>
        Friend Shared ReadOnly Property RSE_Err_CantSaveResource_1Arg() As String
            Get
                Return ResourceManager.GetString("RSE_Err_CantSaveResource_1Arg", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to The value cannot be empty in a resource of type {0}..
        '''</summary>
        Friend Shared ReadOnly Property RSE_Err_CantUseEmptyValue() As String
            Get
                Return ResourceManager.GetString("RSE_Err_CantUseEmptyValue", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to There is already another resource with the name &apos;{0}&apos;..
        '''</summary>
        Friend Shared ReadOnly Property RSE_Err_DuplicateName_1Arg() As String
            Get
                Return ResourceManager.GetString("RSE_Err_DuplicateName_1Arg", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Unexpected error..
        '''</summary>
        Friend Shared ReadOnly Property RSE_Err_InternalException() As String
            Get
                Return ResourceManager.GetString("RSE_Err_InternalException", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Unable to load resource from file &apos;{0}&apos;..
        '''</summary>
        Friend Shared ReadOnly Property RSE_Err_LoadingResource_1Arg() As String
            Get
                Return ResourceManager.GetString("RSE_Err_LoadingResource_1Arg", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Too many files specified.  Please select fewer files and try again..
        '''</summary>
        Friend Shared ReadOnly Property RSE_Err_MaxFilesLimitation() As String
            Get
                Return ResourceManager.GetString("RSE_Err_MaxFilesLimitation", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to &apos;{0}&apos;.
        '''</summary>
        Friend Shared ReadOnly Property RSE_Err_Name() As String
            Get
                Return ResourceManager.GetString("RSE_Err_Name", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to The resource name cannot be empty..
        '''</summary>
        Friend Shared ReadOnly Property RSE_Err_NameBlank() As String
            Get
                Return ResourceManager.GetString("RSE_Err_NameBlank", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to {0}, &apos;{1}&apos;.
        '''</summary>
        Friend Shared ReadOnly Property RSE_Err_NameList() As String
            Get
                Return ResourceManager.GetString("RSE_Err_NameList", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to The current object is auto-generated and only supports renaming through the Managed Resources Editor..
        '''</summary>
        Friend Shared ReadOnly Property RSE_Err_RenameNotSupported() As String
            Get
                Return ResourceManager.GetString("RSE_Err_RenameNotSupported", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to The resource item uses the type &apos;{0}&apos;, which is not supported in this project..
        '''</summary>
        Friend Shared ReadOnly Property RSE_Err_TypeIsNotSupported_1Arg() As String
            Get
                Return ResourceManager.GetString("RSE_Err_TypeIsNotSupported_1Arg", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Unable to load internal localized resource &apos;{0}&apos;..
        '''</summary>
        Friend Shared ReadOnly Property RSE_Err_Unexpected_NoResource_1Arg() As String
            Get
                Return ResourceManager.GetString("RSE_Err_Unexpected_NoResource_1Arg", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to The resource was not of the expected type..
        '''</summary>
        Friend Shared ReadOnly Property RSE_Err_UnexpectedResourceType() As String
            Get
                Return ResourceManager.GetString("RSE_Err_UnexpectedResourceType", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to You are trying to edit a resource file that is a part of another project item (such as a form or a control).  Editing this item could corrupt the project item, and you will have to recover it by hand.  In addition, changes made to this resource file may be lost if further changes are made to the project item.
        '''
        '''Do you really want to edit this file?.
        '''</summary>
        Friend Shared ReadOnly Property RSE_Err_UpdateADependentFile() As String
            Get
                Return ResourceManager.GetString("RSE_Err_UpdateADependentFile", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to The operation has been canceled by the user..
        '''</summary>
        Friend Shared ReadOnly Property RSE_Err_UserCancel() As String
            Get
                Return ResourceManager.GetString("RSE_Err_UserCancel", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to {0} byte(s).
        '''</summary>
        Friend Shared ReadOnly Property RSE_FileSizeFormatBytes_1Arg() As String
            Get
                Return ResourceManager.GetString("RSE_FileSizeFormatBytes_1Arg", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to {0} KB.
        '''</summary>
        Friend Shared ReadOnly Property RSE_FileSizeFormatKB() As String
            Get
                Return ResourceManager.GetString("RSE_FileSizeFormatKB", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to All Files.
        '''</summary>
        Friend Shared ReadOnly Property RSE_Filter_All() As String
            Get
                Return ResourceManager.GetString("RSE_Filter_All", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Audio.
        '''</summary>
        Friend Shared ReadOnly Property RSE_Filter_Audio() As String
            Get
                Return ResourceManager.GetString("RSE_Filter_Audio", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Bitmaps.
        '''</summary>
        Friend Shared ReadOnly Property RSE_Filter_Bitmap() As String
            Get
                Return ResourceManager.GetString("RSE_Filter_Bitmap", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Icons.
        '''</summary>
        Friend Shared ReadOnly Property RSE_Filter_Icon() As String
            Get
                Return ResourceManager.GetString("RSE_Filter_Icon", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Text Files.
        '''</summary>
        Friend Shared ReadOnly Property RSE_Filter_Text() As String
            Get
                Return ResourceManager.GetString("RSE_Filter_Text", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Windows Bitmap.
        '''</summary>
        Friend Shared ReadOnly Property RSE_FilterSave_BMP() As String
            Get
                Return ResourceManager.GetString("RSE_FilterSave_BMP", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Graphics Interchange Format.
        '''</summary>
        Friend Shared ReadOnly Property RSE_FilterSave_GIF() As String
            Get
                Return ResourceManager.GetString("RSE_FilterSave_GIF", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Icon.
        '''</summary>
        Friend Shared ReadOnly Property RSE_FilterSave_Icon() As String
            Get
                Return ResourceManager.GetString("RSE_FilterSave_Icon", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to JPEG File Interchange Format.
        '''</summary>
        Friend Shared ReadOnly Property RSE_FilterSave_JPEG() As String
            Get
                Return ResourceManager.GetString("RSE_FilterSave_JPEG", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Portable Network Graphics.
        '''</summary>
        Friend Shared ReadOnly Property RSE_FilterSave_PNG() As String
            Get
                Return ResourceManager.GetString("RSE_FilterSave_PNG", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Tag Image File Format.
        '''</summary>
        Friend Shared ReadOnly Property RSE_FilterSave_TIFF() As String
            Get
                Return ResourceManager.GetString("RSE_FilterSave_TIFF", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to .
        '''</summary>
        Friend Shared ReadOnly Property RSE_Font_ListView() As String
            Get
                Return ResourceManager.GetString("RSE_Font_ListView", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to .
        '''</summary>
        Friend Shared ReadOnly Property RSE_Font_MenuStrip() As String
            Get
                Return ResourceManager.GetString("RSE_Font_MenuStrip", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to .
        '''</summary>
        Friend Shared ReadOnly Property RSE_Font_StringTable() As String
            Get
                Return ResourceManager.GetString("RSE_Font_StringTable", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to {0} x {1}.
        '''</summary>
        Friend Shared ReadOnly Property RSE_GraphicSizeFormat() As String
            Get
                Return ResourceManager.GetString("RSE_GraphicSizeFormat", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to .
        '''</summary>
        Friend Shared ReadOnly Property RSE_NoBoldFontsInCategoryButtons() As String
            Get
                Return ResourceManager.GetString("RSE_NoBoldFontsInCategoryButtons", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to No code generation.
        '''</summary>
        Friend Shared ReadOnly Property RSE_NoCodeGeneration() As String
            Get
                Return ResourceManager.GetString("RSE_NoCodeGeneration", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to (Value cannot be displayed).
        '''</summary>
        Friend Shared ReadOnly Property RSE_NonEditableValue() As String
            Get
                Return ResourceManager.GetString("RSE_NonEditableValue", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to (Nothing/null).
        '''</summary>
        Friend Shared ReadOnly Property RSE_NothingValue() As String
            Get
                Return ResourceManager.GetString("RSE_NothingValue", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Additional information about the resource.  This property is only meaningful at design time..
        '''</summary>
        Friend Shared ReadOnly Property RSE_PropDesc_Comment() As String
            Get
                Return ResourceManager.GetString("RSE_PropDesc_Comment", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Character encoding of the file..
        '''</summary>
        Friend Shared ReadOnly Property RSE_PropDesc_Encoding() As String
            Get
                Return ResourceManager.GetString("RSE_PropDesc_Encoding", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to The path to the linked resource..
        '''</summary>
        Friend Shared ReadOnly Property RSE_PropDesc_Filename() As String
            Get
                Return ResourceManager.GetString("RSE_PropDesc_Filename", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Specifies whether the file resource is text or binary..
        '''</summary>
        Friend Shared ReadOnly Property RSE_PropDesc_FileType() As String
            Get
                Return ResourceManager.GetString("RSE_PropDesc_FileType", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Name used to identify the resource in code..
        '''</summary>
        Friend Shared ReadOnly Property RSE_PropDesc_Name() As String
            Get
                Return ResourceManager.GetString("RSE_PropDesc_Name", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Specifies whether the resource is embedded or linked.  Embedded resources are saved in the resource file.  Linked resources reside in an external location on disk..
        '''</summary>
        Friend Shared ReadOnly Property RSE_PropDesc_Persistence() As String
            Get
                Return ResourceManager.GetString("RSE_PropDesc_Persistence", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to The resource will be generated as this type in the strongly-typed resource class.  For example, the resource might be generated as a String or Bitmap object..
        '''</summary>
        Friend Shared ReadOnly Property RSE_PropDesc_Type() As String
            Get
                Return ResourceManager.GetString("RSE_PropDesc_Type", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to The value of the resource..
        '''</summary>
        Friend Shared ReadOnly Property RSE_PropDesc_Value() As String
            Get
                Return ResourceManager.GetString("RSE_PropDesc_Value", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Value.
        '''</summary>
        Friend Shared ReadOnly Property RSE_ResourceColumn() As String
            Get
                Return ResourceManager.GetString("RSE_ResourceColumn", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Managed Resources Editor.
        '''</summary>
        Friend Shared ReadOnly Property RSE_ResourceEditor() As String
            Get
                Return ResourceManager.GetString("RSE_ResourceEditor", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Name.
        '''</summary>
        Friend Shared ReadOnly Property RSE_ResourceNameColumn() As String
            Get
                Return ResourceManager.GetString("RSE_ResourceNameColumn", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Resource &apos;{0}&apos; could not be loaded because the file to which it is linked could not be found: {1}..
        '''</summary>
        Friend Shared ReadOnly Property RSE_Task_BadLink_2Args() As String
            Get
                Return ResourceManager.GetString("RSE_Task_BadLink_2Args", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Unable to set the Custom Tool or Custom Tool Namespace properties of this file in order to change strongly-typed resource generation options.  If the project file is checked in, try checking it out..
        '''</summary>
        Friend Shared ReadOnly Property RSE_Task_CantChangeCustomToolOrNamespace() As String
            Get
                Return ResourceManager.GetString("RSE_Task_CantChangeCustomToolOrNamespace", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Resource &apos;{0}&apos; could not be instantiated.  {1}.
        '''</summary>
        Friend Shared ReadOnly Property RSE_Task_CantInstantiate_2Args() As String
            Get
                Return ResourceManager.GetString("RSE_Task_CantInstantiate_2Args", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to The resource name &apos;{0}&apos; is not a valid identifier..
        '''</summary>
        Friend Shared ReadOnly Property RSE_Task_InvalidName_1Arg() As String
            Get
                Return ResourceManager.GetString("RSE_Task_InvalidName_1Arg", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Resource &apos;{0}&apos; has a name that is not recommended and that may cause compilation errors in your code.  Please choose another name..
        '''</summary>
        Friend Shared ReadOnly Property RSE_Task_NonrecommendedName_1Arg() As String
            Get
                Return ResourceManager.GetString("RSE_Task_NonrecommendedName_1Arg", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Double-click here to enable strongly-typed resources for this file..
        '''</summary>
        Friend Shared ReadOnly Property RSE_Task_WarningCustomToolNotSet() As String
            Get
                Return ResourceManager.GetString("RSE_Task_WarningCustomToolNotSet", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Binary File.
        '''</summary>
        Friend Shared ReadOnly Property RSE_Type_BinaryFile() As String
            Get
                Return ResourceManager.GetString("RSE_Type_BinaryFile", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Windows Bitmap.
        '''</summary>
        Friend Shared ReadOnly Property RSE_Type_BMP() As String
            Get
                Return ResourceManager.GetString("RSE_Type_BMP", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to EXIF Image.
        '''</summary>
        Friend Shared ReadOnly Property RSE_Type_EXIF() As String
            Get
                Return ResourceManager.GetString("RSE_Type_EXIF", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Graphics Interchange Format.
        '''</summary>
        Friend Shared ReadOnly Property RSE_Type_GIF() As String
            Get
                Return ResourceManager.GetString("RSE_Type_GIF", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Icon.
        '''</summary>
        Friend Shared ReadOnly Property RSE_Type_Icon() As String
            Get
                Return ResourceManager.GetString("RSE_Type_Icon", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to JPEG File Interchange Format.
        '''</summary>
        Friend Shared ReadOnly Property RSE_Type_JPEG() As String
            Get
                Return ResourceManager.GetString("RSE_Type_JPEG", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Windows Bitmap.
        '''</summary>
        Friend Shared ReadOnly Property RSE_Type_MEMBMP() As String
            Get
                Return ResourceManager.GetString("RSE_Type_MEMBMP", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Portable Network Graphics.
        '''</summary>
        Friend Shared ReadOnly Property RSE_Type_PNG() As String
            Get
                Return ResourceManager.GetString("RSE_Type_PNG", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Text File.
        '''</summary>
        Friend Shared ReadOnly Property RSE_Type_TextFile() As String
            Get
                Return ResourceManager.GetString("RSE_Type_TextFile", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Tag Image File Format.
        '''</summary>
        Friend Shared ReadOnly Property RSE_Type_TIFF() As String
            Get
                Return ResourceManager.GetString("RSE_Type_TIFF", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Wave Sound.
        '''</summary>
        Friend Shared ReadOnly Property RSE_Type_Wave() As String
            Get
                Return ResourceManager.GetString("RSE_Type_Wave", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Type.
        '''</summary>
        Friend Shared ReadOnly Property RSE_TypeColumn() As String
            Get
                Return ResourceManager.GetString("RSE_TypeColumn", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Add {0} new resource(s).
        '''</summary>
        Friend Shared ReadOnly Property RSE_Undo_AddResources_1Arg() As String
            Get
                Return ResourceManager.GetString("RSE_Undo_AddResources_1Arg", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Change resource name.
        '''</summary>
        Friend Shared ReadOnly Property RSE_Undo_ChangeName() As String
            Get
                Return ResourceManager.GetString("RSE_Undo_ChangeName", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Delete values in {0} cell(s).
        '''</summary>
        Friend Shared ReadOnly Property RSE_Undo_DeleteResourceCell() As String
            Get
                Return ResourceManager.GetString("RSE_Undo_DeleteResourceCell", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Remove {0} resource(s).
        '''</summary>
        Friend Shared ReadOnly Property RSE_Undo_RemoveResources_1Arg() As String
            Get
                Return ResourceManager.GetString("RSE_Undo_RemoveResources_1Arg", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to (Unknown type).
        '''</summary>
        Friend Shared ReadOnly Property RSE_UnknownType() As String
            Get
                Return ResourceManager.GetString("RSE_UnknownType", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Failed to create or open file..
        '''</summary>
        Friend Shared ReadOnly Property SD_CODEGEN_FAILEDOPENCREATEEXTENDINGFILE() As String
            Get
                Return ResourceManager.GetString("SD_CODEGEN_FAILEDOPENCREATEEXTENDINGFILE", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to This class allows you to handle specific events on the settings class:.
        '''</summary>
        Friend Shared ReadOnly Property SD_CODEGENCMT_COMMON1() As String
            Get
                Return ResourceManager.GetString("SD_CODEGENCMT_COMMON1", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to  The SettingChanging event is raised before a setting&apos;s value is changed..
        '''</summary>
        Friend Shared ReadOnly Property SD_CODEGENCMT_COMMON2() As String
            Get
                Return ResourceManager.GetString("SD_CODEGENCMT_COMMON2", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to  The PropertyChanged event is raised after a setting&apos;s value is changed..
        '''</summary>
        Friend Shared ReadOnly Property SD_CODEGENCMT_COMMON3() As String
            Get
                Return ResourceManager.GetString("SD_CODEGENCMT_COMMON3", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to  The SettingsLoaded event is raised after the setting values are loaded..
        '''</summary>
        Friend Shared ReadOnly Property SD_CODEGENCMT_COMMON4() As String
            Get
                Return ResourceManager.GetString("SD_CODEGENCMT_COMMON4", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to  The SettingsSaving event is raised before the setting values are saved..
        '''</summary>
        Friend Shared ReadOnly Property SD_CODEGENCMT_COMMON5() As String
            Get
                Return ResourceManager.GetString("SD_CODEGENCMT_COMMON5", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Add code to handle the SettingChangingEvent event here..
        '''</summary>
        Friend Shared ReadOnly Property SD_CODEGENCMT_HANDLE_CHANGING() As String
            Get
                Return ResourceManager.GetString("SD_CODEGENCMT_HANDLE_CHANGING", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Add code to handle the SettingsSaving event here..
        '''</summary>
        Friend Shared ReadOnly Property SD_CODEGENCMT_HANDLE_SAVING() As String
            Get
                Return ResourceManager.GetString("SD_CODEGENCMT_HANDLE_SAVING", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to To add event handlers for saving and changing settings, uncomment the lines below:.
        '''</summary>
        Friend Shared ReadOnly Property SD_CODEGENCMT_HOWTO_ATTACHEVTS() As String
            Get
                Return ResourceManager.GetString("SD_CODEGENCMT_HOWTO_ATTACHEVTS", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Application.
        '''</summary>
        Friend Shared ReadOnly Property SD_ComboBoxItem_ApplicationScope() As String
            Get
                Return ResourceManager.GetString("SD_ComboBoxItem_ApplicationScope", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Browse....
        '''</summary>
        Friend Shared ReadOnly Property SD_ComboBoxItem_BrowseType() As String
            Get
                Return ResourceManager.GetString("SD_ComboBoxItem_BrowseType", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Connection string.
        '''</summary>
        Friend Shared ReadOnly Property SD_ComboBoxItem_ConnectionStringType() As String
            Get
                Return ResourceManager.GetString("SD_ComboBoxItem_ConnectionStringType", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to User.
        '''</summary>
        Friend Shared ReadOnly Property SD_ComboBoxItem_UserScope() As String
            Get
                Return ResourceManager.GetString("SD_ComboBoxItem_UserScope", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Application (Web).
        '''</summary>
        Friend Shared ReadOnly Property SD_ComboBoxItem_WebApplicationScope() As String
            Get
                Return ResourceManager.GetString("SD_ComboBoxItem_WebApplicationScope", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Web Service URL.
        '''</summary>
        Friend Shared ReadOnly Property SD_ComboBoxItem_WebReferenceType() As String
            Get
                Return ResourceManager.GetString("SD_ComboBoxItem_WebReferenceType", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to User (Web).
        '''</summary>
        Friend Shared ReadOnly Property SD_ComboBoxItem_WebUserScope() As String
            Get
                Return ResourceManager.GetString("SD_ComboBoxItem_WebUserScope", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Description of the setting..
        '''</summary>
        Friend Shared ReadOnly Property SD_DESCR_Description() As String
            Get
                Return ResourceManager.GetString("SD_DESCR_Description", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Specifies whether or not the default setting value should be generated in the strongly-typed settings class..
        '''</summary>
        Friend Shared ReadOnly Property SD_DESCR_GenerateDefaultValueInCode() As String
            Get
                Return ResourceManager.GetString("SD_DESCR_GenerateDefaultValueInCode", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Specifies the group to which this Settings file belongs..
        '''</summary>
        Friend Shared ReadOnly Property SD_DESCR_Group() As String
            Get
                Return ResourceManager.GetString("SD_DESCR_Group", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Description of the group to which this Settings file belongs..
        '''</summary>
        Friend Shared ReadOnly Property SD_DESCR_GroupDescription() As String
            Get
                Return ResourceManager.GetString("SD_DESCR_GroupDescription", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Name used to identify the setting..
        '''</summary>
        Friend Shared ReadOnly Property SD_DESCR_Name() As String
            Get
                Return ResourceManager.GetString("SD_DESCR_Name", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to The provider (System.Configuration.Provider.ProviderBase) used to manage the setting..
        '''</summary>
        Friend Shared ReadOnly Property SD_DESCR_Provider() As String
            Get
                Return ResourceManager.GetString("SD_DESCR_Provider", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Indicates whether the setting should roam when Windows roaming profiles are enabled..
        '''</summary>
        Friend Shared ReadOnly Property SD_DESCR_Roaming() As String
            Get
                Return ResourceManager.GetString("SD_DESCR_Roaming", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Specifies whether the setting is per-application (read-only) or per-user (read-write)..
        '''</summary>
        Friend Shared ReadOnly Property SD_DESCR_Scope() As String
            Get
                Return ResourceManager.GetString("SD_DESCR_Scope", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to The setting will be generated as this type in the strongly-typed settings class. For example, the setting might be generated as a String or Integer object..
        '''</summary>
        Friend Shared ReadOnly Property SD_DESCR_SerializedSettingType() As String
            Get
                Return ResourceManager.GetString("SD_DESCR_SerializedSettingType", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to The current value for the setting..
        '''</summary>
        Friend Shared ReadOnly Property SD_DESCR_Value() As String
            Get
                Return ResourceManager.GetString("SD_DESCR_Value", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Abstract types are not supported..
        '''</summary>
        Friend Shared ReadOnly Property SD_ERR_AbstractTypesNotSupported_1Arg() As String
            Get
                Return ResourceManager.GetString("SD_ERR_AbstractTypesNotSupported_1Arg", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to The username/password combination cannot be authenticated..
        '''</summary>
        Friend Shared ReadOnly Property SD_ERR_CantAuthenticate() As String
            Get
                Return ResourceManager.GetString("SD_ERR_CantAuthenticate", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to The settings file cannot be modified at this time..
        '''</summary>
        Friend Shared ReadOnly Property SD_ERR_CantEditInDebugMode() As String
            Get
                Return ResourceManager.GetString("SD_ERR_CantEditInDebugMode", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Unable to load settings file.  It might be corrupted or contain invalid XML or contain duplicate identifiers..
        '''</summary>
        Friend Shared ReadOnly Property SD_Err_CantLoadSettingsFile() As String
            Get
                Return ResourceManager.GetString("SD_Err_CantLoadSettingsFile", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to There is already another setting with the name &apos;{0}&apos;..
        '''</summary>
        Friend Shared ReadOnly Property SD_ERR_DuplicateName_1Arg() As String
            Get
                Return ResourceManager.GetString("SD_ERR_DuplicateName_1Arg", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to There are already settings with the following names: {0}..
        '''</summary>
        Friend Shared ReadOnly Property SD_ERR_DuplicateNameList_1Arg() As String
            Get
                Return ResourceManager.GetString("SD_ERR_DuplicateNameList_1Arg", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Generic types are not supported..
        '''</summary>
        Friend Shared ReadOnly Property SD_ERR_GenericTypesNotSupported_1Arg() As String
            Get
                Return ResourceManager.GetString("SD_ERR_GenericTypesNotSupported_1Arg", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to &apos;{0}&apos; is not a valid identifier..
        '''</summary>
        Friend Shared ReadOnly Property SD_ERR_InvalidIdentifier_1Arg() As String
            Get
                Return ResourceManager.GetString("SD_ERR_InvalidIdentifier_1Arg", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to &apos;{0}&apos; is not a valid type name..
        '''</summary>
        Friend Shared ReadOnly Property SD_ERR_InvalidTypeName_1Arg() As String
            Get
                Return ResourceManager.GetString("SD_ERR_InvalidTypeName_1Arg", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to &apos;{0}&apos; cannot be converted to an instance of type &apos;{1}&apos;..
        '''</summary>
        Friend Shared ReadOnly Property SD_ERR_InvalidValue_2Arg() As String
            Get
                Return ResourceManager.GetString("SD_ERR_InvalidValue_2Arg", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to The current object is auto-generated and does not support modifying parameters..
        '''</summary>
        Friend Shared ReadOnly Property SD_ERR_ModifyParamsNotSupported() As String
            Get
                Return ResourceManager.GetString("SD_ERR_ModifyParamsNotSupported", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to The setting name cannot be empty..
        '''</summary>
        Friend Shared ReadOnly Property SD_ERR_NameEmpty() As String
            Get
                Return ResourceManager.GetString("SD_ERR_NameEmpty", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to The current object is auto-generated and only supports renaming through the Settings Designer..
        '''</summary>
        Friend Shared ReadOnly Property SD_ERR_RenameNotSupported() As String
            Get
                Return ResourceManager.GetString("SD_ERR_RenameNotSupported", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to The following type names were not understood: &apos;{0}&apos;.  Make sure you have references to these types..
        '''</summary>
        Friend Shared ReadOnly Property SD_ERR_UnreferencedTypeNameList_1Arg() As String
            Get
                Return ResourceManager.GetString("SD_ERR_UnreferencedTypeNameList_1Arg", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to An error occurred while reading the app.config file. The file might be corrupted or contain invalid XML..
        '''</summary>
        Friend Shared ReadOnly Property SD_FailedToLoadAppConfigValues() As String
            Get
                Return ResourceManager.GetString("SD_FailedToLoadAppConfigValues", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to An error occurred while saving values to the app.config file. The file might be corrupted or contain invalid XML..
        '''</summary>
        Friend Shared ReadOnly Property SD_FailedToSaveAppConfigValues() As String
            Get
                Return ResourceManager.GetString("SD_FailedToSaveAppConfigValues", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Application settings allow you to store and retrieve property settings and other information for your application dynamically. For example, the application can save a user&apos;s color preferences, then retrieve them the next time it runs..
        '''</summary>
        Friend Shared ReadOnly Property SD_FullDescriptionText() As String
            Get
                Return ResourceManager.GetString("SD_FullDescriptionText", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Name.
        '''</summary>
        Friend Shared ReadOnly Property SD_GridViewNameColumnHeaderText() As String
            Get
                Return ResourceManager.GetString("SD_GridViewNameColumnHeaderText", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Scope.
        '''</summary>
        Friend Shared ReadOnly Property SD_GridViewScopeColumnHeaderText() As String
            Get
                Return ResourceManager.GetString("SD_GridViewScopeColumnHeaderText", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Type.
        '''</summary>
        Friend Shared ReadOnly Property SD_GridViewTypeColumnHeaderText() As String
            Get
                Return ResourceManager.GetString("SD_GridViewTypeColumnHeaderText", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Value.
        '''</summary>
        Friend Shared ReadOnly Property SD_GridViewValueColumnHeaderText() As String
            Get
                Return ResourceManager.GetString("SD_GridViewValueColumnHeaderText", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to This connection string appears to contain sensitive data (for example, a password), which is required to connect to the database. However, storing sensitive data in the connection string can be a security risk. Do you want to include sensitive data in the connection string?.
        '''</summary>
        Friend Shared ReadOnly Property SD_IncludeSensitiveInfoInConnectionStringWarning() As String
            Get
                Return ResourceManager.GetString("SD_IncludeSensitiveInfoInConnectionStringWarning", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Learn more about application settings....
        '''</summary>
        Friend Shared ReadOnly Property SD_LinkPartOfDescriptionText() As String
            Get
                Return ResourceManager.GetString("SD_LinkPartOfDescriptionText", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to &amp;Add Setting.
        '''</summary>
        Friend Shared ReadOnly Property SD_MNU_AddSettingText() As String
            Get
                Return ResourceManager.GetString("SD_MNU_AddSettingText", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to R&amp;emove Setting.
        '''</summary>
        Friend Shared ReadOnly Property SD_MNU_RemoveSettingText() As String
            Get
                Return ResourceManager.GetString("SD_MNU_RemoveSettingText", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to New values from the app.config file were automatically added.
        '''</summary>
        Friend Shared ReadOnly Property SD_NewValuesAdded() As String
            Get
                Return ResourceManager.GetString("SD_NewValuesAdded", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to The current value in the .settings file is &apos;{0}&apos;
        '''The new value in the app.config file is &apos;{1}&apos;
        '''
        '''Do you want to update the value in the .settings file?.
        '''</summary>
        Friend Shared ReadOnly Property SD_ReplaceValueWithAppConfigValue() As String
            Get
                Return ResourceManager.GetString("SD_ReplaceValueWithAppConfigValue", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Value of setting &apos;{0}&apos; was changed in the app.config file..
        '''</summary>
        Friend Shared ReadOnly Property SD_ReplaceValueWithAppConfigValueTitle() As String
            Get
                Return ResourceManager.GetString("SD_ReplaceValueWithAppConfigValueTitle", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Select a Type.
        '''</summary>
        Friend Shared ReadOnly Property SD_SelectATypeTreeView_AccessibleName() As String
            Get
                Return ResourceManager.GetString("SD_SelectATypeTreeView_AccessibleName", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to My.Settings Auto-Save Functionality.
        '''</summary>
        Friend Shared ReadOnly Property SD_SFG_AutoSaveRegionText() As String
            Get
                Return ResourceManager.GetString("SD_SFG_AutoSaveRegionText", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to The following files will be deleted:
        '''
        '''{0}.
        '''</summary>
        Friend Shared ReadOnly Property SD_SyncFiles_1Arg() As String
            Get
                Return ResourceManager.GetString("SD_SyncFiles_1Arg", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to No user.config files were found in any of the following locations:
        '''
        '''{0}.
        '''</summary>
        Friend Shared ReadOnly Property SD_SyncFilesNoFilesFound_1Arg() As String
            Get
                Return ResourceManager.GetString("SD_SyncFilesNoFilesFound_1Arg", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to One or more user.config files was not removed..
        '''</summary>
        Friend Shared ReadOnly Property SD_SyncFilesOneOrMoreFailed() As String
            Get
                Return ResourceManager.GetString("SD_SyncFilesOneOrMoreFailed", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Description changed.
        '''</summary>
        Friend Shared ReadOnly Property SD_UndoTran_DescriptionChanged() As String
            Get
                Return ResourceManager.GetString("SD_UndoTran_DescriptionChanged", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Generate default value in code changed.
        '''</summary>
        Friend Shared ReadOnly Property SD_UndoTran_GenerateDefaultValueInCode() As String
            Get
                Return ResourceManager.GetString("SD_UndoTran_GenerateDefaultValueInCode", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Name changed.
        '''</summary>
        Friend Shared ReadOnly Property SD_UndoTran_NameChanged() As String
            Get
                Return ResourceManager.GetString("SD_UndoTran_NameChanged", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Provider changed.
        '''</summary>
        Friend Shared ReadOnly Property SD_UndoTran_ProviderChanged() As String
            Get
                Return ResourceManager.GetString("SD_UndoTran_ProviderChanged", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Remove {0} setting(s).
        '''</summary>
        Friend Shared ReadOnly Property SD_UndoTran_RemoveMultipleSettings_1Arg() As String
            Get
                Return ResourceManager.GetString("SD_UndoTran_RemoveMultipleSettings_1Arg", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Roaming changed.
        '''</summary>
        Friend Shared ReadOnly Property SD_UndoTran_RoamingChanged() As String
            Get
                Return ResourceManager.GetString("SD_UndoTran_RoamingChanged", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Scope changed.
        '''</summary>
        Friend Shared ReadOnly Property SD_UndoTran_ScopeChanged() As String
            Get
                Return ResourceManager.GetString("SD_UndoTran_ScopeChanged", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Value changed.
        '''</summary>
        Friend Shared ReadOnly Property SD_UndoTran_SerializedValueChanged() As String
            Get
                Return ResourceManager.GetString("SD_UndoTran_SerializedValueChanged", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Type changed.
        '''</summary>
        Friend Shared ReadOnly Property SD_UndoTran_TypeChanged() As String
            Get
                Return ResourceManager.GetString("SD_UndoTran_TypeChanged", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Type &apos;{0}&apos; is not defined..
        '''</summary>
        Friend Shared ReadOnly Property SD_UnknownType() As String
            Get
                Return ResourceManager.GetString("SD_UnknownType", resourceCulture)
            End Get
        End Property
        
        '''<summary>
        '''  Looks up a localized string similar to Failed to generate file: {0}.
        '''</summary>
        Friend Shared ReadOnly Property SingleFileGenerator_FailedToGenerateFile_1Arg() As String
            Get
                Return ResourceManager.GetString("SingleFileGenerator_FailedToGenerateFile_1Arg", resourceCulture)
            End Get
        End Property

    '''<summary>
    '''  Looks up a localized string similar to To enable client application services, you must set the Target Framework for your application to .NET Framework 3.5 or later. In C#, you can do this on the Application property page. In Visual Basic, you can do this one the Compile property page by clicking Advanced Compile Options.
    '''</summary>
    Friend Shared ReadOnly Property PPG_Services_VersionWarning() As String
        Get
            Return ResourceManager.GetString("PPG_Services_VersionWarning", resourceCulture)
        End Get
    End Property
    
    End Class
End Namespace
